function[groupData,config,powConfig,retStruct] = ps2_ecog_subjPow_anal_LR(configNum,plotFlag)
% This function categorizes left vs. right signals. 
%It carries out two major tasks. First, it collects data across all
%electrodes and stores it in a single data structure. To do so, 
%it selects a subset of information stored for each electrode 
%(e.g., it does not collect the entire power matrix for left button press trials, but instead collapses across trials). Second, it has functions
%that allow for statistical analysis across subjects (e.g., functions 
%that collapse data from all electrodes within a subject, to allow
%across subject analyses). Third, has several functions to allow for stats
%and plotting. It will test the following hypotheses:
%1) left v. right selective contacts have a limited spatial distribution
%(motor, premotor, parietal)
%2) The timing of these signals will reveal a bimodality, with pre-response
% signals reflecting motor/premotor, and post-response signals reflecting
% selective attention signals.

%Ashwin G. Ramayya 02-09-2015

clear global
global CONFIGNUM
CONFIGNUM = configNum;

[config] = getConfig_local(configNum);
[groupData,powConfig] = collect_local();

% update anatRegion field labels (l vs. r)
[groupData] = upAnat_local(groupData);

[retStruct] = getRetStruct_local(groupData,config);

if exist('plotFlag','var') && plotFlag == 1
    %%%% how frequent are positive and negative representations observed?
    [chi2stat,p,df,obs_cat,obs_freq,expec_freq] = doChi2_local(groupData,config);
    swagFig; pie(obs_cat,[0 0 0 1]);
    % per subject
    [p,stats,num_sig_z] = counts_perm_local(groupData,retStruct.retain_leftRight,config.alfa/2);
    
    %%%% where are they in the brain? (ROI analysis)
    %ROI-based analysis
    [regStruct] = roi_lrCounts_local(groupData,config,retStruct.roiList,retStruct.retain_roi,1);
    
    %%%%% temporal dynamics
    ret = retStruct.retain_left|retStruct.retain_right|retStruct.retain_leftRight;
    make_timing_heatmap(groupData(ret),config,powConfig); 
    
    %%% mean responses
    %left regions
    ret = regStruct.left_reg;
    roi_avgResponses_local(1,groupData,powConfig,config,retStruct.roiList...
        (ret), retStruct.retain_roi(ret))

    %right regions
    ret = regStruct.right_reg;
    roi_avgResponses_local(1,groupData,powConfig,config,retStruct.roiList...
        (ret), retStruct.retain_roi(ret))

    


end
% FUNCTIONS BELOW %
function [] = roi_avgResponses_local(xSubjFlag,groupData,powConfig,config,roiList,retain_roi)
[numElecs,retain_left,...
        retain_right,retain_leftRight,...
        retain_nsig] = idSig_local(groupData,config);
%swagFig([0.7504    0.0057    0.1387    0.9455]);
%yL = [-4 4];
for r = 1:length(roiList)
    %subplot(length(roiList),1,r)
    swagFig;
    
    if xSubjFlag
        [groupData_subj] = collapse_w_subj(groupData,retain_roi{r});
    else
        groupData_subj = groupData(retain_roi{r});
    end
    
    
    if ~isempty(fieldnames(groupData_subj));
        tVec = cat(1,groupData_subj.tVec);
        plotSEM(powConfig.timeWins_lbl,nanmean(tVec,1),SEM(tVec),[.6 .6 .6]);
    end
%     hold all
%     [groupData_subj] = collapse_w_subj(groupData,retain_roi{r}&retain_pos);
%     if ~isempty(fieldnames(groupData_subj));
%         tVec = cat(1,groupData_subj.tVec);
%         plotSEM(powConfig.timeWins_lbl,nanmean(tVec,1),SEM(tVec),[.6 1 .6]);
%     end
%     hold all
%     [groupData_subj] = collapse_w_subj(groupData,retain_roi{r}&retain_neg);
%     if ~isempty(fieldnames(groupData_subj));
%         tVec = cat(1,groupData_subj.tVec);
%         plotSEM(powConfig.timeWins_lbl,nanmean(tVec,1),SEM(tVec),[1 .6 .6]);    
%     end
    swagAxes(gca,12,'Time from feedback (ms)','t-statistic (pos - neg)',roiList{r})
    %set(gca,'ylim',yL)
    [~,zero_ind] = min(abs(powConfig.timeWins_lbl-0));
    drawVertLine(gca,zero_ind)
end



function[p,stats,num_sig_z] = counts_perm_local(groupData,retain,alfa,min_elecs);
subj_list  =unique({groupData.subj});
iters = 10000;
if ~exist('min_elecs','var')||isempty(min_elecs)
    min_elecs = 1;
end
for s = 1:length(subj_list)
   subj_ret =  strcmp({groupData.subj},subj_list{s});
   num_elecs(s) = sum(subj_ret);
   num_sig = sum(subj_ret&retain);
   
   % simulate null distribution for this subject
   num_sig_null = binornd(num_elecs(end),alfa,[1 iters]);
      
   % z-score by binomial dist
   num_sig_z(s) = (num_sig - mean(num_sig_null))/std(num_sig_null);
end
ret = num_elecs>=min_elecs;
[~,p,~,stats] = ttest(num_sig_z(ret));

function[p,stats,num_sig_z1,num_sig_z2] = counts2_perm_local(groupData,retain,alfa1,groupData2,retain2,alfa2,min_elecs);
subj_list  =unique([{groupData.subj} {groupData2.subj}]);
iters = 10000;
for s = 1:length(subj_list)
   subj_ret =  strcmp({groupData.subj},subj_list{s});
   num_elecs1(s) = sum(subj_ret);
   num_sig1 = sum(subj_ret&retain);
   num_sig_null = binornd(num_elecs1(end),alfa1,[1 iters]);
   num_sig_z1(s) = (num_sig1 - mean(num_sig_null))/std(num_sig_null);

   subj_ret =  strcmp({groupData2.subj},subj_list{s});
   num_elecs2(s) = sum(subj_ret);
   num_sig2 = sum(subj_ret&retain2);
   num_sig_null = binornd(num_elecs2(end),alfa2,[1 iters]);
   num_sig_z2(s) = (num_sig2 - mean(num_sig_null))/std(num_sig_null);
   %num_sig_null = binornd(num_elecs1(end),max([num_sig2/num_elecs2(end) min_alfa]),[1 iters]);
   %num_sig_z(s) = (num_sig1 - mean(num_sig_null))/std(num_sig_null);
   
end
ret = num_elecs1>=min_elecs & num_elecs2>=min_elecs;
[~,p,~,stats] = ttest(num_sig_z1(ret),num_sig_z2(ret));


function[groupData] = upAnat_local(groupData)
xyz = cat(1,groupData.xyz);
for i = 1:length(groupData);
    if xyz(i,1)<=0
        groupData(i).anatRegion = ['L_' groupData(i).anatRegion];
        groupData(i).ROI = ['L_' groupData(i).ROI{1}]; groupData(i).ROI = {groupData(i).ROI};
    else
        groupData(i).anatRegion = ['R_' groupData(i).anatRegion];
        groupData(i).ROI = ['R_' groupData(i).ROI{1}];groupData(i).ROI = {groupData(i).ROI};
    end
end
function[retStruct] = getRetStruct_local(groupData,config)
[numElecs,retain_left,...
    retain_right,retain_leftRight,...
    retain_nsig] = idSig_local(groupData,config);

% make retain phasic and tonic 
    onset_vec = nan(1,length(groupData));
    onset_vec(retain_left) = [groupData(retain_left).posClusOnset];
    onset_vec(retain_right) = [groupData(retain_right).negClusOnset];

    offset_vec = nan(1,length(groupData));
    offset_vec(retain_left) = [groupData(retain_left).posClusOffset];
    offset_vec(retain_right) = [groupData(retain_right).negClusOffset];

    phasic_idx =onset_vec>config.onset_thresh(1)& ...
        onset_vec<config.onset_thresh(2) &...
        (offset_vec-onset_vec)<config.duration_thresh;
    tonic_idx = onset_vec>config.onset_thresh(1)& ...
        onset_vec<config.onset_thresh(2) &...
        (offset_vec-onset_vec)>=config.duration_thresh;

   % roiList = unique({groupData.anatRegion});
    roiList = unique([groupData.ROI]);
    xyz = cat(1,groupData.xyz);
    for i = 1:length(roiList)
        %ret = strcmp({groupData.anatRegion},roiList{i});
        ret = strcmp([groupData.ROI],roiList{i});
        retain_roi{i} = ret; 
        numSubj(i) = length(unique({groupData(ret).subj}));
        
        if ~isempty(regexp(roiList{i},'OTHER','once'))
            numSubj(i) = 0;
        end
    end
    
    %remove regions with less than 5 subj
    rmInd = numSubj<config.min_subj;
    roiList(rmInd) = [];
    retain_roi(rmInd) = [];
    
    %sort by label
    for i = 1:length(roiList)
        thisLbl = regexp(roiList{i},'_','split');
        uROI_list{i} = thisLbl{2};
    end
    [~,sortIdx] = sort(uROI_list);
    roiList = roiList(sortIdx);
    retain_roi = retain_roi(sortIdx);
    
    %update retStruct
    retStruct.retain_left = retain_left;
    retStruct.retain_right = retain_right;
    retStruct.retain_leftRight = retain_leftRight;
    retStruct.retain_nsig = retain_nsig;
    retStruct.retain_phasic = phasic_idx;
    retStruct.retain_tonic = tonic_idx;
    retStruct.retain_roi = retain_roi;
    retStruct.roiList = roiList;
 
    

function [groupData_subj] = collapse_w_subj(groupData,retain);
groupData = groupData(retain);
subj_list = unique({groupData.subj});
names = fieldnames(groupData);
groupData_subj = struct;
for s = 1:length(subj_list)
    retain_subj = strcmp(subj_list{s},{groupData.subj});
    for n = 1:length(names)
        switch names{n}
            case {'subj','eName','acc','anatRegion','anatRegion_indiv','ROI','eType'} %grab first entry
                groupData_subj(s).(names{n}) = ...
                    groupData(find(retain_subj,1)).(names{n}); 
            case {'posClusP','negClusP'} % take min
                groupData_subj(s).(names{n}) = ...
                    min(cat(1,groupData(retain_subj).(names{n})));
            otherwise % get mean value
                groupData_subj(s).(names{n}) = ...
                    nanmean(cat(1,groupData(retain_subj).(names{n})),1);
        end
    end
end
 
function [regStruct] = roi_lrCounts_local(groupData,config,roiList,retain_roi,min_elecs)
    [numElecs,retain_left,...
        retain_right,retain_leftRight,...
        retain_nsig] = idSig_local(groupData,config);
    %left more freq. than chance
    for i = 1:length(roiList); 
        [p_left(i),stats_left(i)] = ...
            counts_perm_local(groupData(retain_roi{i}),retain_left(retain_roi{i}),config.alfa);
        left_frac(i) = mean(retain_left(retain_roi{i}));
    end
    %right more freq. than chance
    for i = 1:length(roiList); 
        [p_right(i),stats_right(i)] = ...
            counts_perm_local(groupData(retain_roi{i}),retain_right(retain_roi{i}),config.alfa);
        right_frac(i) = mean(retain_right(retain_roi{i}));
    end
    %regional biases
    for i = 1:length(roiList); 
        [p_leftRight(i),stats_leftRight(i)] = ...
            counts2_perm_local(groupData(retain_roi{i}),retain_left(retain_roi{i}),config.alfa,...
            groupData(retain_roi{i}),retain_right(retain_roi{i}),config.alfa,min_elecs);
    end
     %posNeg more freq. than chance
     for i = 1:length(roiList); 
%         [p_posNeg(i),stats_posNeg(i)] = ...
%             counts_perm_local(groupData(retain_roi{i}),retain_posNeg(retain_roi{i}),config.alfa);
         leftRight_frac(i) = mean(retain_leftRight(retain_roi{i}));
     end
    
    
    % alfa thresh
    alfa_thresh =  fdr([p_left p_right],config.alfa);%fdr([p_pos p_neg p_posNeg],config.alfa);
    
    % regStruct (region struct)
    regStruct.left_reg = p_left<=alfa_thresh&left_frac>=0.05;
    regStruct.right_reg = p_right<=alfa_thresh&right_frac>=0.05;
    regStruct.bias_left = p_leftRight<=alfa_thresh &[stats_leftRight.tstat]>0;
    regStruct.bias_right = p_leftRight<=alfa_thresh & [stats_leftRight.tstat]<0;
    
    swagFig([ 0.4504    0.7212    0.5598    0.2117]);
    bar([left_frac;right_frac;leftRight_frac]','stacked')
    set(gca,'xtick',1:length(roiList),'xticklabel',roiList);
    swagAxes(gca,12,'Region of interest','Fraction of electrodes')
    legend('location','northeastoutside',{'Positive', 'Negative'});

function [] = make_timing_heatmap(groupData,config,powConfig)
[numElecs,retain_left,...
        retain_right,retain_leftRight,...
        retain_nsig] = idSig_local(groupData,config);
  
    left_onset = [groupData(retain_left).posClusOnset];
    right_onset = [groupData(retain_right).negClusOnset];
    onset = [left_onset,right_onset];
    
    left_offset = [groupData(retain_left).posClusOffset];
    right_offset = [groupData(retain_right).negClusOffset];    
    offset = [left_offset,right_offset];

    left_dur = [groupData(retain_left).posClusDur];
    right_dur = [groupData(retain_right).negClusDur];    
    dur = [left_dur,right_offset];
    
    % timing heat map
    timeBinSize = 100;
    timeBinStep = 10;
    timeBinDur = powConfig.postMS+powConfig.priorMS;
    t_ends=[timeBinSize:timeBinStep:timeBinDur]-powConfig.priorMS;
    t_starts = t_ends-timeBinSize+1;
    timeBins = [t_starts' t_ends'];
    t_lbl = mean(timeBins,2);
    timing_heatmap = nan(size(timeBins,1),size(timeBins,1));
    for t_on = 1:size(timeBins,1)
        for t_offset = 1:size(timeBins,1)
            
            onset_match = (onset<timeBins(t_on,2) & onset>=timeBins(t_on,1));
            offset_match = (offset<timeBins(t_offset,2) & offset>=timeBins(t_offset,1));

            numContacts = sum(onset_match&offset_match);
            timing_heatmap(t_offset,t_on) = numContacts;
                
        end
    end
    timing_heatmap(timing_heatmap<1) = nan;
    swagFig;
    imagescnan(timing_heatmap);
    set(gca,'ydir','normal','clim',[-15 15]); colorbar
    [~,zero_ind] = min(abs(t_lbl));  [~,end_ind] = min(abs(t_lbl-powConfig.postMS)); 
    xl = get(gca,'xlim');
    hold all;
    plot([xl(1):xl(2)],[xl(1):xl(2)],'linestyle','-','linewidth',3,'color','k')
    swagAxes(gca,12,'Onset (ms)','Offset (ms)')
    %set(gca,'xlim',[zero_ind end_ind],'ylim',[zero_ind end_ind])
    xt = get(gca,'xtick');yt = get(gca,'ytick');
    set(gca,'xticklabel',t_lbl(xt),'yticklabel',t_lbl(yt))
    drawVertLine(gca,zero_ind)
    
function[chi2stat,p,df,obs_cat,obs_freq,expec_freq] = doChi2_local(groupData,config)
    alfa = config.alfa;
    %identify sig. contacts
    [numElecs,retain_left,retain_right,retain_leftRight,...
        retain_nsig] = idSig_local(groupData,config);
    
    % more sig than chance?
    obs_freq = [sum(~retain_nsig) sum(retain_nsig)];
    expec_freq = [alfa*numElecs (1-alfa)*numElecs];
    [chi2stat,p,df] = chi2test([obs_freq' expec_freq']);
    obs_cat = [sum(retain_left) sum(retain_right) sum(retain_leftRight) sum(retain_nsig)];
  
function[numElecs,retain_left,retain_right,retain_leftRight,retain_nsig] = idSig_local(groupData,config)
    alfa = config.alfa;
    numElecs = length(groupData);
    retain_left = ([groupData.posClusP]<alfa)&isnan([groupData.negClusP]);
    retain_right = ([groupData.negClusP]<alfa)&isnan([groupData.posClusP]);
    retain_leftRight = ([groupData.posClusP]<alfa)&([groupData.negClusP]<alfa);
    retain_nsig = ~retain_left&~retain_right&~retain_leftRight;

function [config] = getConfig_local(configNum)
dirs = ps2_dirs;

% alfa
config.alfa = 0.05;

%clus stats info
config.compar = 'fb_LR';
config.powConfigNum = 1;
config.fRange = [70 200];
config.diffLbl = 'leftVRight';
config.clusStatsInfo_rootDir  = fullfile(dirs.analyses,...
    'ecog','subjPow','clusStats');
config.clusStatsInfo_dir = fullfile(config.clusStatsInfo_rootDir,config.compar,...
    ['powConfig' num2str(config.powConfigNum) '-' num2str(config.fRange(1)) '-' num2str(config.fRange(2))]);

% phasic and tonic thresh
config.onset_thresh = [-1000 0];
config.offset_thresh = 0;
config.duration_thresh = 1000;

%min subj 
config.min_subj = 5;
%save dir 
config.saveDir = fullfile(dirs.analyses,'ecog','subjPow',...
    'analyses','clusLR',[config.compar '-' num2str(config.powConfigNum) '-' num2str(config.fRange(1)) '-' num2str(config.fRange(2))]);

function [groupData,powConfig] = collect_local()
global CONFIGNUM
config = getConfig_local(CONFIGNUM);
[subjList] = ps2_ecog_subjPow_getSubjList;
cd_mkdir(config.saveDir);
saveFile = 'groupData.mat';

if exist(saveFile,'file')
    load(saveFile)
else
    groupData = struct;
    count = 0;
    sStart = 1;
    eStart = 1;
end
for s = sStart:length(subjList)
    [elecList] =  ps2_ecog_subjPow_getElecList(subjList(s).subj);

    % get behavioral stuff here
    [fbEvents] = ps2_ecog_subjPow_getSubjEv(subjList(s).subj);
    acc = mean([fbEvents.correct]);
   
    for e = eStart:length(elecList)
       if s == 1 && e == 1
            % load powConifg;
            [~,~,~,~,~,powConfig] = ...
            ps2_ecog_subjPow_getSubjPow(subjList(s).subj,elecList(e).eNames,config.powConfigNum);
       end

      count = count + 1;
      [compPowStruct] = ps2_ecog_subjPow_doComp(subjList(s).subj,elecList(e).eNames,...
          config.compar,config.powConfigNum,config.fRange);
      clusStats = compPowStruct.(config.diffLbl);

      % update structure
      groupData(count).subj = subjList(s).subj;
      groupData(count).eName = elecList(e).eNames;

      % beh
      groupData(count).acc = acc;

      %anat (currently uses snapped information). Stores anatomical labels
      %from each individual brain as well as those obtained from
      %registering the post-op ct to the group brain.
      bpTalStruct = getBipolarSubjElecs(elecList(e).subj_list{1},1);
      thisTal = [bpTalStruct.avgSurf]; indivTal = [bpTalStruct.indivSurf];
      thisName = regexp(elecList(e).eNames,'_','split');
      eStruct = bpTalStruct(strcmp({bpTalStruct.eNames},thisName{1}));
      eTal = thisTal(strcmp({bpTalStruct.eNames},thisName{1}));
      eTal_indiv = indivTal(strcmp({bpTalStruct.eNames},thisName{1}));
      
      % update
      groupData(count).xyz =  [eTal.x_snap eTal.y_snap eTal.z_snap];%elecList(e).xyz;
      groupData(count).anatRegion = eTal.anatRegion_snap;
      groupData(count).anatRegion_indiv = eTal_indiv.anatRegion_snap;
      
      if strcmp(eStruct.eType,'D') % update anatRegion based on depth label
        groupData(count).anatRegion = parseDepth_local(eStruct);
        groupData(count).anatRegion_indiv = groupData(count).anatRegion;
      end
      
      groupData(count).ROI = getROI_local(eTal,eStruct);
      groupData(count).eType = eStruct.eType;
      
      % t vec
      groupData(count).tVec = clusStats.tVec;

      % summary clus stats stuff
      if ~isempty(clusStats.posClusStats(1))&&clusStats.posClusStatsP(1)<config.alfa;
          groupData(count).posClusStat = clusStats.posClusStats(1);
          groupData(count).posClusP = clusStats.posClusStatsP(1);
          groupData(count).posClusOnset = clusStats.posClusInd{1}(1);
          groupData(count).posClusOffset = clusStats.posClusInd{1}(end);
          groupData(count).posClusDur = clusStats.posClusInd{1}(end)-clusStats.posClusInd{1}(1);
          clusIdx = ismember(powConfig.timeWins_lbl,clusStats.posClusInd{1});
          [groupData(count).posClusPeak,peakOnset]...
              = max(abs(clusStats.tVec(clusIdx)));
           groupData(count).posClusPeakOnset = clusStats.posClusInd{1}(peakOnset);
      else
          groupData(count).posClusStat = nan;
          groupData(count).posClusP = nan;
          groupData(count).posClusOnset = nan;
          groupData(count).posClusOffset = nan;
          groupData(count).posClusDur = nan;
          groupData(count).posClusPeak = nan;
          groupData(count).posClusPeakOnset = nan;
      end

      if ~isempty(clusStats.negClusStats(1))&&clusStats.negClusStatsP(1)<config.alfa;
          groupData(count).negClusStat = clusStats.negClusStats(1);
          groupData(count).negClusP = clusStats.negClusStatsP(1);
          groupData(count).negClusOnset = clusStats.negClusInd{1}(1);
          groupData(count).negClusOffset = clusStats.negClusInd{1}(end);
          groupData(count).negClusDur = clusStats.negClusInd{1}(end)-clusStats.negClusInd{1}(1);
                clusIdx = ismember(powConfig.timeWins_lbl,clusStats.negClusInd{1});
          [groupData(count).negClusPeak,peakOnset]...
              = max(abs(clusStats.tVec(clusIdx)));
          groupData(count).negClusPeakOnset = clusStats.negClusInd{1}(peakOnset);
      else
          groupData(count).negClusStat = nan;
          groupData(count).negClusP = nan;
          groupData(count).negClusOnset = nan;
          groupData(count).negClusOffset = nan;
          groupData(count).negClusDur = nan;
          groupData(count).negClusPeak = nan;
          groupData(count).negClusPeakOnset = nan;
      end
        %iteratively save
        cd(config.saveDir);
        eStart = e+1;
        if eStart>length(elecList)
            sStart = s+1;
            eStart = 1;
        end
        save(saveFile,'groupData','powConfig','count','sStart','eStart')
        disp(count);    
    end
end
function [anatRegion] = parseDepth_local(eStruct)
% get mtl leads
region_list = {'hipp','ec','amy','phc',...
    'prc','mtl','fusiform','itg','mtg','stg'};

lbl_list = {'hippocampus','entorhinal',...
    'amygdala','parahippocampal','parahippocampal',...
    'MTL','fusiform','inferiortemporal','middletemporal',...
    'superiortemporal'};

% combine regions
anatRegion = 'unknown';
for i = 1:length(region_list)
    [idx] = get_mtl_leads(eStruct(1).subject,region_list{i});
    if any(ismember(eStruct.channel,idx))
       anatRegion = lbl_list{i};
    end
end
function [ROI_list] = getROI_local(thisTal,bpTalStruct)
%keyboard
ROI_list = cell(1,length(thisTal));

% get mtl leads
[hippIdx,~,~,js_error] = get_mtl_leads(bpTalStruct(1).subject,'hipp');
phcIdx = get_mtl_leads(bpTalStruct(1).subject,'phc');
prcIdx = get_mtl_leads(bpTalStruct(1).subject,'prc');
ecIdx = get_mtl_leads(bpTalStruct(1).subject,'ec');
%mIdx = get_mtl_leads(bpTalStruct(1).subject,'mtl');
mtlIdx = unique([hippIdx;phcIdx;prcIdx;ecIdx]);

fusIdx = get_mtl_leads(bpTalStruct(1).subject,'fusiform');

itgIdx = get_mtl_leads(bpTalStruct(1).subject,'itg');
mtgIdx = get_mtl_leads(bpTalStruct(1).subject,'mtg');
stgIdx = get_mtl_leads(bpTalStruct(1).subject,'stg');
temp_idx = unique([itgIdx;mtgIdx;stgIdx]);
if js_error == 1
    disp([bpTalStruct(1).subject '...Joel stein not working'])
end

for i = 1:length(thisTal)
    switch bpTalStruct(i).eType
        case {'D'}
            if any(ismember(bpTalStruct(i).channel,mtlIdx))
                ROI_list{i} = 'MTL';
            elseif any(ismember(bpTalStruct(i).channel,fusIdx))
                ROI_list{i} = 'fusiform';
            elseif any(ismember(bpTalStruct(i).channel,temp_idx))
                ROI_list{i} = 'temporal';
            else
                ROI_list{i} = 'OTHER';
            end
        otherwise
            switch thisTal(i).anatRegion_snap
                % frontal pole,
                case {'medialorbitofrontal','lateralorbitofrontal'}
                    ROI_list{i} = 'orbitofrontal';
                case {'parsorbitalis','parstrianglularis','parsopercularis'}
                    ROI_list{i} = 'vlPFC';
                case {'caudalmiddlefrontal','rostralmiddlefrontal'}
                    ROI_list{i} = 'dlPFC';
                case {'superiorfrontal','rostralanteriorcingulate','caudalanteriorcingulate'}
                   ROI_list{i} = 'ant_front_med'; 
                case {'paracentral','posteriorcingulate','isthmuscingulate'}
                    ROI_list{i} = 'post_front_med';
                case {'precentral','postcentral'}
                    ROI_list{i} = 'sensorimotor';
                case {'superiorparietal','supramarginal','inferiorparietal'}
                    ROI_list{i} = 'parietal';
                case {'bankssts','inferiortemporal','middletemporal','superiortemporal','temporalpole','transversetemporal'}     
                    ROI_list{i} = 'temporal';
                case {'fusiform'}
                    ROI_list{i} = 'fusiform';
                case {'cuneus','lateraloccipital','lingual','pericalcarine'}
                     ROI_list{i} = 'occipital';
                case {'parahippocampal','entorhinal'}
                     ROI_list{i} = 'MTL';
                otherwise
                     ROI_list{i} = 'OTHER';
            end
     
    end
end

