function[groupData,config,powConfig,retStruct] = ps2_ecog_subjPow_anal_posNeg(configNum,plotFlag)
% This function categorizes outcome valence signals. 
%It carries out two major tasks. First, it collects data across all
%electrodes and stores it in a single data structure. To do so, 
%it selects a subset of information stored for each electrode 
%(e.g., it does not collect the entire power matrix for positive
%feedback, but instead collapses across trials). Second, it has functions
%that allow for statistical analysis across subjects (e.g., functions 
%that collapse data from all electrodes within a subject, to allow
%across subject analyses). Third, has several functions to allow for 
%plotting (e.g., making a timing heat map)

% fig 1 ... methods
% fig 2 ... eg. subj showing diverse signals on a grid
% fig 3 ... pos v. neg counts pie; regional distribution (fraction of each
% region); brain map
% fig 4 ... timing diversity; phasic v. tonic e.g.
% fig 5 ... timing regional distribution (phasic v. tonic counts) v. ROI
% onset duration differences
% fig 6 ... % pair-wise, % early v. late, % RPE; phasic v. tonic, pos v.
% neg
% fig 7 ... x subj corr

% To Do:
%(X) collapse across subj; and compare onset and offset
%(X) phasic and tonic distribution across regions
%( ) example figures 
%( ) pair-wise, early v. late, and RPE (regression-based on sig. clus ind)
%( ) searchlight brain plots ----positive signals timing; neg. signals
%timing
%( ) across subj corr

clear global
global CONFIGNUM
CONFIGNUM = configNum;

[config] = getConfig_local(configNum);
[groupData,powConfig] = collect_local();

% update anatRegion field labels (l vs. r)
[groupData] = upAnat_local(groupData);

[retStruct] = getRetStruct_local(groupData,config);

if exist('plotFlag','var') && plotFlag == 1
    %%%% how frequent are positive and negative representations observed?
    [chi2stat,p,df,obs_cat,obs_freq,expec_freq] = doChi2_local(groupData,config);
    swagFig; pie(obs_cat,[0 0 0 1]);
    % per subject
    [p,stats,num_sig_z] = counts_perm_local(groupData,retStruct.retain_posNeg,config.alfa/2);
    
    
    %%%%% temporal dynamics
    % pos v. neg timing 
    [p,stats] = posNeg_onsetDur_local(groupData,powConfig,config);
      
    %timing heatmaps
    % pos
    % phasic
    ret = retStruct.retain_pos;
    make_timing_heatmap(groupData(ret),config,powConfig); 

    % neg
    % phasic
    ret = retStruct.retain_neg;
    make_timing_heatmap(groupData(ret),config,powConfig); 

    %%%% where are they in the brain? (ROI analysis)
        %ROI-based analysis
        [regStruct] = roi_posNegCounts_local(groupData,config,retStruct.roiList,retStruct.retain_roi,1);
      
        % phasic and tonic counts in each region
        [phasTonStruct] = roi_phasicTonicCounts_local(groupData,config,retStruct,regStruct);
        
       %Left vs. Right
       [uROI_list,alfa_thresh,p_lr_pos,stats_lr_pos,p_lr_neg,stats_lr_neg] = ...
       roi_lr_counts(groupData,config,retStruct.retain_pos,retStruct.retain_neg,...
       retStruct.roiList,...
       retStruct.retain_roi);
      
    % peak onset and duration times for each region
    % pos > chance regions (sorted by onset)
    ret = find(regStruct.pos_reg);
    posNegFlag = 1;
    sortFlag = 1;
    [roiList_sort_pos,p_ons_pos,stats_ons_pos,retain_roi_sort] = ...
        roi_timingBar_local(1,posNegFlag,'PeakOnset',sortFlag,groupData,...
        config,retStruct.roiList(ret),retStruct.retain_roi(ret));
     sortFlag = 0;
     [roiList_sort_pos,p_dur_pos,stats_dur_pos] = roi_timingBar_local(1,posNegFlag,...
         'Dur',sortFlag,groupData,config,retStruct.roiList(ret),retStruct.retain_roi(ret));
     
    % neg > chance regions (sorted by onset)
    ret = find(regStruct.neg_reg);
    posNegFlag = 2;
    sortFlag = 1;
    [roiList_sort_neg,p_ons_neg,stats_ons_neg,~] = ...
        roi_timingBar_local(1,posNegFlag,'PeakOnset',sortFlag,groupData,...
        config,retStruct.roiList(ret),retStruct.retain_roi(ret));
     sortFlag = 0;
     [roiList_sort_neg,p_dur_neg,stats_dur_neg,~] =...
         roi_timingBar_local(1,posNegFlag,'Dur',sortFlag,groupData,config,...
         retStruct.roiList(ret),retStruct.retain_roi(ret));
alfa_thresh = fdr([p_ons_pos,p_ons_neg],0.2);

    
%  OLD L V R ANALYSIS
%lr_posNegCounts_local(groupData,retStruct,config);   
%     AVG Time Course (theres a function for this)
%     PHASIC V. TONIC    
%     % What is the frequency of phasic/tonic pos and neg signals?
%     phasicTonic_counts_local(groupData,config,retStruct.retain_phasic,retStruct.retain_tonic)
%     % avg. phasic and tonic responses
%     phasicTonic_avgResponse_local(groupData,config,powConfig,retStruct.retain_phasic,retStruct.retain_tonic)
%     % where are phasic and tonic in the brain?
%     roi_phasTonicCounts_local(groupData,config,retStruct.retain_roi,retStruct.roiList,retStruct.retain_phasic,retStruct.retain_tonic)

% phasic vs. tonic freqs
%     min_elecs = 5;min_alfa = config.alfa;
%     posInd = retStruct.retain_pos;negInd = retStruct.retain_neg;
%     % compare pos and neg in phasic and tonic freq
%     [p,stats,~,~] = counts2_perm_local(groupData(posInd),...
%         retStruct.retain_phasic(posInd),groupData(negInd),retStruct.retain_phasic(negInd),min_alfa,...
%         min_elecs);    
%     [p,stats,~,~] = counts2_perm_local(groupData(posInd),...
%         retStruct.retain_tonic(posInd),groupData(negInd),retStruct.retain_tonic(negInd),min_alfa,...
%         min_elecs);

end
% FUNCTIONS BELOW %
function[p,stats,num_sig_z] = counts_perm_local(groupData,retain,alfa,min_elecs);
subj_list  =unique({groupData.subj});
iters = 10000;
if ~exist('min_elecs','var')||isempty(min_elecs)
    min_elecs = 1;
end
for s = 1:length(subj_list)
   subj_ret =  strcmp({groupData.subj},subj_list{s});
   num_elecs(s) = sum(subj_ret);
   num_sig = sum(subj_ret&retain);
   
   % simulate null distribution for this subject
   num_sig_null = binornd(num_elecs(end),alfa,[1 iters]);
      
   % z-score by binomial dist
   num_sig_z(s) = (num_sig - mean(num_sig_null))/std(num_sig_null);
end
ret = num_elecs>=min_elecs;
[~,p,~,stats] = ttest(num_sig_z(ret));

function[p,stats,num_sig_z1,num_sig_z2] = counts2_perm_local(groupData,retain,alfa1,groupData2,retain2,alfa2,min_elecs);
subj_list  =unique([{groupData.subj} {groupData2.subj}]);
iters = 10000;
for s = 1:length(subj_list)
   subj_ret =  strcmp({groupData.subj},subj_list{s});
   num_elecs1(s) = sum(subj_ret);
   num_sig1 = sum(subj_ret&retain);
   num_sig_null = binornd(num_elecs1(end),alfa1,[1 iters]);
   num_sig_z1(s) = (num_sig1 - mean(num_sig_null))/std(num_sig_null);

   subj_ret =  strcmp({groupData2.subj},subj_list{s});
   num_elecs2(s) = sum(subj_ret);
   num_sig2 = sum(subj_ret&retain2);
   num_sig_null = binornd(num_elecs2(end),alfa2,[1 iters]);
   num_sig_z2(s) = (num_sig2 - mean(num_sig_null))/std(num_sig_null);
   %num_sig_null = binornd(num_elecs1(end),max([num_sig2/num_elecs2(end) min_alfa]),[1 iters]);
   %num_sig_z(s) = (num_sig1 - mean(num_sig_null))/std(num_sig_null);
   
end
ret = num_elecs1>=min_elecs & num_elecs2>=min_elecs;
[~,p,~,stats] = ttest(num_sig_z1(ret),num_sig_z2(ret));


function[groupData] = upAnat_local(groupData)
xyz = cat(1,groupData.xyz);
for i = 1:length(groupData);
    if xyz(i,1)<=0
        groupData(i).anatRegion = ['L_' groupData(i).anatRegion];
        groupData(i).ROI = ['L_' groupData(i).ROI{1}]; groupData(i).ROI = {groupData(i).ROI};
    else
        groupData(i).anatRegion = ['R_' groupData(i).anatRegion];
        groupData(i).ROI = ['R_' groupData(i).ROI{1}];groupData(i).ROI = {groupData(i).ROI};
    end
end
function[retStruct] = getRetStruct_local(groupData,config)
[numElecs,retain_pos,...
    retain_neg,retain_posNeg,...
    retain_nsig] = idSig_local(groupData,config);

% make retain phasic and tonic 
    onset_vec = nan(1,length(groupData));
    onset_vec(retain_pos) = [groupData(retain_pos).posClusOnset];
    onset_vec(retain_neg) = [groupData(retain_neg).negClusOnset];

    offset_vec = nan(1,length(groupData));
    offset_vec(retain_pos) = [groupData(retain_pos).posClusOffset];
    offset_vec(retain_neg) = [groupData(retain_neg).negClusOffset];

    phasic_idx =onset_vec>config.onset_thresh(1)& ...
        onset_vec<config.onset_thresh(2) &...
        (offset_vec-onset_vec)<config.duration_thresh;
    tonic_idx = onset_vec>config.onset_thresh(1)& ...
        onset_vec<config.onset_thresh(2) &...
        (offset_vec-onset_vec)>=config.duration_thresh;

   % roiList = unique({groupData.anatRegion});
    roiList = unique([groupData.ROI]);
    xyz = cat(1,groupData.xyz);
    for i = 1:length(roiList)
        %ret = strcmp({groupData.anatRegion},roiList{i});
        ret = strcmp([groupData.ROI],roiList{i});
        retain_roi{i} = ret; 
        numSubj(i) = length(unique({groupData(ret).subj}));
        
        if ~isempty(regexp(roiList{i},'OTHER','once'))
            numSubj(i) = 0;
        end
    end
    
    %remove regions with less than 5 subj
    rmInd = numSubj<config.min_subj;
    roiList(rmInd) = [];
    retain_roi(rmInd) = [];
    
    %sort by label
    for i = 1:length(roiList)
        thisLbl = regexp(roiList{i},'_','split');
        uROI_list{i} = thisLbl{2};
    end
    [~,sortIdx] = sort(uROI_list);
    roiList = roiList(sortIdx);
    retain_roi = retain_roi(sortIdx);
    
    %update retStruct
    retStruct.retain_pos = retain_pos;
    retStruct.retain_neg = retain_neg;
    retStruct.retain_posNeg = retain_posNeg;
    retStruct.retain_nsig = retain_nsig;
    retStruct.retain_phasic = phasic_idx;
    retStruct.retain_tonic = tonic_idx;
    retStruct.retain_roi = retain_roi;
    retStruct.roiList = roiList;
 
    
function[] = phasicTonic_avgResponse_local(groupData,config,powConfig,retain_phasic,retain_tonic)
[numElecs,retain_pos,retain_neg,retain_posNeg,...
        retain_nsig] = idSig_local(groupData,config);
    
swagFig;hold all
[groupData_pos] = collapse_w_subj(groupData,retain_pos&retain_phasic);
tVec = cat(1,groupData_pos.tVec);
plotSEM(1:size(tVec,2),nanmean(tVec,1),SEM(tVec),[.6 1 .6]);
   
[groupData_neg] = collapse_w_subj(groupData,retain_neg&retain_phasic);
tVec = cat(1,groupData_neg.tVec);
plotSEM(1:size(tVec,2),nanmean(tVec,1),SEM(tVec),[1 .6 .6]);
swagAxes(gca,12,'Time from feedback (ms)','t-statistic (pos - neg)','')
xt = get(gca,'xtick');
set(gca,'xticklabel',powConfig.timeWins_lbl(xt));
[~,zero_ind] = min(abs(powConfig.timeWins_lbl-0));
drawVertLine(gca,zero_ind)

swagFig;hold all
[groupData_pos] = collapse_w_subj(groupData,retain_pos&retain_tonic);
tVec = cat(1,groupData_pos.tVec);
plotSEM(1:size(tVec,2),nanmean(tVec,1),SEM(tVec),[.6 1 .6]);
   
[groupData_neg] = collapse_w_subj(groupData,retain_neg&retain_tonic);
tVec = cat(1,groupData_neg.tVec);
plotSEM(1:size(tVec,2),nanmean(tVec,1),SEM(tVec),[1 .6 .6]);
swagAxes(gca,12,'Time from feedback (ms)','t-statistic (pos - neg)','')
xt = get(gca,'xtick');set(gca,'xticklabel',powConfig.timeWins_lbl(xt));
[~,zero_ind] = min(abs(powConfig.timeWins_lbl-0));
drawVertLine(gca,zero_ind)



function [roiList_sort,p,stats,retain_roi_sort] = roi_timingBar_local(xSubjFlag,posNegFlag,timing_field,sortFlag,groupData,config,roiList,retain_roi,timingField)
[~,retain_pos,retain_neg] = idSig_local(groupData,config);

if posNegFlag == 1
    thisRetain = retain_pos;
elseif posNegFlag == 2
    thisRetain = retain_neg;
end
mean_onset = nan(1,length(roiList));
sem_onset = nan(1,length(roiList));

for r = 1:length(roiList)
    if xSubjFlag == 1
        [groupData_subj] = collapse_w_subj(groupData,retain_roi{r}&thisRetain);
        [groupData_all] = collapse_w_subj(groupData,~retain_roi{r}&thisRetain);
    else
        groupData_subj = groupData(retain_roi{r}&thisRetain);
        groupData_all = groupData(~retain_roi{r}&thisRetain);
    end
    if ~isempty(fieldnames(groupData_subj))&&~isempty(groupData_subj)
        if posNegFlag == 1
            onset = [groupData_subj.(['posClus' timing_field])];
            mean_onset_all = mean([groupData_all.(['posClus' timing_field])]);
            
        elseif posNegFlag ==2
            onset = [groupData_subj.(['negClus' timing_field])];
            mean_onset_all = mean([groupData_all.(['negClus' timing_field])]);
        end
        mean_onset(r) = mean(onset);
        sem_onset(r) = SEM(onset');
        [~,p(r),~,stats(r)] = ttest(onset,mean_onset_all);
    end
end    
% sort by mean onset
if sortFlag == 1
    [~,sortIdx] = sort(mean_onset);
    roiList_sort = roiList(sortIdx);
    retain_roi_sort = retain_roi(sortIdx);
    mean_onset = mean_onset(sortIdx);
    sem_onset = sem_onset(sortIdx);
    p = p(sortIdx);
    stats = stats(sortIdx);
else
    roiList_sort = roiList;
    retain_roi_sort = retain_roi;
end
%plot
swagFig([ 0.6699    0.6863    0.2781    0.1515]);hold all
bar(1:length(roiList),mean_onset,'facecolor',[.6 .6 .6]);
errorbar(1:length(roiList), mean_onset, sem_onset,'.k','linewidth',3)
swagAxes(gca,12,'Region','Time (ms)');
set(gca,'xlim',[.5 length(roiList)+.5])
set(gca,'xtick',1:length(roiList),'xticklabel',roiList_sort);
function [p,stats] = posNeg_onsetDur_local(groupData,powConfig,config)
[numElecs,retain_pos,...
        retain_neg,retain_posNeg,...
        retain_nsig] = idSig_local(groupData,config);
swagFig;hold all
[groupData_pos] = collapse_w_subj(groupData,retain_pos);
onset = [groupData_pos.posClusPeakOnset]; offset = [groupData_pos.posClusDur];
error_ellipse(cov(onset',offset'),[mean(onset) mean(offset)])
%errorEllipse(mean(onset),mean(offset),SEM(onset'),SEM(offset'),[.6 1 .6],[.2 .2 .2])
swagAxes(gca,12,'Onset (ms)','Duration (ms)','',1)

[groupData_neg] = collapse_w_subj(groupData,retain_neg);
onset = [groupData_neg.negClusPeakOnset]; offset = [groupData_neg.negClusDur];
error_ellipse(cov(onset',offset'),[mean(onset) mean(offset)])
%errorEllipse(mean(onset),mean(offset),SEM(onset'),SEM(offset'),[1 .6 .6],[.2 .2 .2])
    swagAxes(gca,12,'Onset (ms)','Duration (ms)','',1)
[~,p(1),~,stats(1)] = ttest2([groupData_pos.posClusPeakOnset],[groupData_neg.negClusPeakOnset]);
[~,p(2),~,stats(2)] = ttest2([groupData_pos.posClusDur],[groupData_neg.negClusDur]);


function [groupData_subj] = collapse_w_subj(groupData,retain);
groupData = groupData(retain);
subj_list = unique({groupData.subj});
names = fieldnames(groupData);
groupData_subj = struct;
for s = 1:length(subj_list)
    retain_subj = strcmp(subj_list{s},{groupData.subj});
    for n = 1:length(names)
        switch names{n}
            case {'subj','eName','acc','anatRegion','anatRegion_indiv','ROI','eType'} %grab first entry
                groupData_subj(s).(names{n}) = ...
                    groupData(find(retain_subj,1)).(names{n}); 
            case {'posClusP','negClusP'} % take min
                groupData_subj(s).(names{n}) = ...
                    min(cat(1,groupData(retain_subj).(names{n})));
            otherwise % get mean value
                groupData_subj(s).(names{n}) = ...
                    nanmean(cat(1,groupData(retain_subj).(names{n})),1);
        end
    end
end
 
function [pos_asymm_ret,neg_asymm_ret] = lr_posNegCounts_local(groupData,retStruct,config)
roiList = retStruct.roiList;
xyz = cat(1,groupData.xyz);
l_ind = [xyz(:,1)<=0]';
retain_pos = retStruct.retain_pos;
retain_neg = retStruct.retain_neg;


% all
[chi2stat_lr,p_lr,pos_frac,neg_frac,exp_frac] = ...
    doLR_local(true(1,length(groupData)),l_ind,retain_pos,retain_neg);
swagFig;
subplot(1,3,1)
pie(pos_frac/sum(pos_frac));title('Pos Contacts')
subplot(1,3,2)
pie(neg_frac/sum(neg_frac));title('Neg Contacts')
subplot(1,3,3)
pie(exp_frac);title('Expec Counts')


%roi
for r = 1:length(roiList)
    ret = retStruct.retain_roi{r};
    [chi2stat_lr_roi(r,:),p_lr_roi(r,:)] = ...
        doLR_local(ret,l_ind,retain_pos,retain_neg);
end

%alfa = fdr([p_lr(:,1)' p_lr(:,2)'],config.alfa);
alfa = config.alfa;
pos_asymm_ret = p_lr_roi(:,1)<=alfa;
neg_asymm_ret = p_lr_roi(:,2)<=alfa;

function [chi2stat_lr,p_lr,pos_frac,neg_frac,exp_freq] = doLR_local(ret,l_ind,retain_pos,retain_neg)
% Left vs. Right
exp_freq = [sum(ret&l_ind)/sum(ret) sum(ret&~l_ind)/sum(ret)];
obs_pos = [sum(ret&retain_pos&l_ind) sum(ret&retain_pos&~l_ind)];
exp_pos = sum(ret&retain_pos)*exp_freq;
[chi2stat_lr(1,1),p_lr(1,1)] = chi2test([obs_pos' exp_pos']);

pos_frac(1,1) = sum(ret&retain_pos&l_ind)/sum(ret);
pos_frac(1,2) = sum(ret&retain_pos&~l_ind)/sum(ret);

obs_neg = [sum(ret&retain_neg&l_ind) sum(ret&retain_neg&~l_ind)];
exp_neg = sum(ret)*exp_freq;
[chi2stat_lr(1,2),p_lr(1,2)] = chi2test([obs_neg' exp_neg']);
neg_frac(1,1) = sum(ret&retain_neg&l_ind)/sum(ret);
neg_frac(1,2) = sum(ret&retain_neg&~l_ind)/sum(ret);
function[] = phasicTonic_counts_local(groupData,config,retain_phasic,retain_tonic)
[numElecs,retain_pos,...
        retain_neg,retain_posNeg,...
        retain_nsig] = idSig_local(groupData,config);
counts = [sum(retain_pos&retain_phasic),sum(retain_pos&retain_tonic);...
                sum(retain_neg&retain_phasic), sum(retain_neg&retain_tonic)];
            
freq_pos= [sum(retain_phasic&retain_pos)/(sum(retain_pos)) ...
    sum(retain_tonic&retain_pos)/(sum(retain_pos))];            
freq_neg= [sum(retain_phasic&retain_neg)/(sum(retain_neg)) ...
    sum(retain_tonic&retain_neg)/(sum(retain_neg))];
            
swagFig
bar([freq_pos; freq_neg],'stacked');
swagAxes(gca,12,'Region of interest','Fraction of electrodes')
legend('location','northeastoutside',{'Positive', 'Negative'});


%pos vs. neg freqs
[chi2stat_pos,p_pos] = chi2test([counts(1,:)' freq_neg'*(sum(retain_pos))]);

function [regStruct] = roi_posNegCounts_local(groupData,config,roiList,retain_roi,min_elecs)
    [numElecs,retain_pos,...
        retain_neg,retain_posNeg,...
        retain_nsig] = idSig_local(groupData,config);
    %pos more freq. than chance
    for i = 1:length(roiList); 
        [p_pos(i),stats_pos(i)] = ...
            counts_perm_local(groupData(retain_roi{i}),retain_pos(retain_roi{i}),config.alfa);
        pos_frac(i) = mean(retain_pos(retain_roi{i}));
    end
    %neg more freq. than chance
    for i = 1:length(roiList); 
        [p_neg(i),stats_neg(i)] = ...
            counts_perm_local(groupData(retain_roi{i}),retain_neg(retain_roi{i}),config.alfa);
        neg_frac(i) = mean(retain_neg(retain_roi{i}));
    end
    %regional biases
    for i = 1:length(roiList); 
        [p_posNeg(i),stats_posNeg(i)] = ...
            counts2_perm_local(groupData(retain_roi{i}),retain_pos(retain_roi{i}),config.alfa,...
            groupData(retain_roi{i}),retain_neg(retain_roi{i}),config.alfa,min_elecs);
    end
     %posNeg more freq. than chance
     for i = 1:length(roiList); 
%         [p_posNeg(i),stats_posNeg(i)] = ...
%             counts_perm_local(groupData(retain_roi{i}),retain_posNeg(retain_roi{i}),config.alfa);
         posNeg_frac(i) = mean(retain_posNeg(retain_roi{i}));
     end
    
    
    % alfa thresh
    alfa_thresh =  fdr([p_pos p_neg],config.alfa);%fdr([p_pos p_neg p_posNeg],config.alfa);
    
    % regStruct (region struct)
    regStruct.pos_reg = p_pos<=alfa_thresh&pos_frac>=0.05;
    regStruct.neg_reg = p_neg<=alfa_thresh&neg_frac>=0.05;
    regStruct.bias_pos = p_posNeg<=alfa_thresh &[stats_posNeg.tstat]>0;
    regStruct.bias_neg = p_posNeg<=alfa_thresh & [stats_posNeg.tstat]<0;
    
    swagFig([ 0.4504    0.7212    0.5598    0.2117]);
    bar([pos_frac;neg_frac;posNeg_frac]','stacked')
    set(gca,'xtick',1:length(roiList),'xticklabel',roiList);
    swagAxes(gca,12,'Region of interest','Fraction of electrodes')
    legend('location','northeastoutside',{'Positive', 'Negative'});

    
function[uROI_list,alfa_thresh_lr,p_lr_pos,stats_lr_pos,p_lr_neg,stats_lr_neg] = roi_lr_counts(groupData,config,retain_pos,retain_neg,roiList,retain_roi)
    for i = 1:length(roiList)
        thisLbl = regexp(roiList{i},'_','split');
        uROI_list{i} = thisLbl{2};
    end
    uROI_list = unique(uROI_list);
    
    for i = 1:length(uROI_list); 
        roi_ind = ~cellfun(@isempty,regexp(roiList,uROI_list{i}));
        l_ind = roi_ind&~cellfun(@isempty,regexp(roiList,'L_'));
        r_ind = roi_ind&~cellfun(@isempty,regexp(roiList,'R_'));
        
        if ~any(l_ind) || ~any(r_ind)
            p_lr_pos(i) = nan;
            stats_lr_pos(i) = struct('tstat',[],'df',[],'sd',[]);
            p_lr_neg(i) = nan;
            stats_lr_neg(i) = struct('tstat',[],'df',[],'sd',[]);
        else
        [p_lr_pos(i),stats_lr_pos(i),z] = ...
            counts2_perm_local(groupData(retain_roi{l_ind}),retain_pos(retain_roi{l_ind}),...
            groupData(retain_roi{r_ind}),retain_pos(retain_roi{r_ind}),config.alfa,1);
        frac_pos_l(i) = mean(retain_pos(retain_roi{l_ind}));
        frac_pos_r(i) = mean(retain_pos(retain_roi{r_ind}));
        
        [p_lr_neg(i),stats_lr_neg(i),z] = ...
        counts2_perm_local(groupData(retain_roi{l_ind}),retain_neg(retain_roi{l_ind}),...
        groupData(retain_roi{r_ind}),retain_neg(retain_roi{r_ind}),config.alfa,1);
        
        frac_neg_l(i) = mean(retain_neg(retain_roi{l_ind}));
        frac_neg_r(i) = mean(retain_neg(retain_roi{r_ind}));
        
        end
        
    end
    
    alfa_thresh_lr = fdr([p_lr_pos, p_lr_neg],0.05);
 
function [phasTonStruct] = roi_phasicTonicCounts_local(groupData,config,retStruct,regStruct)

roiList = retStruct.roiList;
retain_roi = retStruct.retain_roi;
retain_phasic = retStruct.retain_phasic;
retain_tonic = retStruct.retain_tonic;
retain_pos = retStruct.retain_pos;
retain_neg = retStruct.retain_neg;

phasic_pos_frac_mean = sum(retain_phasic&retain_pos)/sum(retain_pos);
tonic_pos_frac_mean = sum(retain_tonic&retain_pos)/sum(retain_pos);

phasic_neg_frac_mean = sum(retain_phasic&retain_neg)/sum(retain_neg);
tonic_neg_frac_mean = sum(retain_tonic&retain_neg)/sum(retain_neg);

%pos regions
% phasic
    %pos
    for i = 1:length(roiList); 
        [phasic_pos_p(i),phasic_pos_stats(i)] = ...
            counts_perm_local(groupData(retain_roi{i}&retain_pos),retain_phasic(retain_roi{i}&retain_pos),phasic_pos_frac_mean);
        phasic_pos_frac(i) = sum(retain_roi{i}&retain_pos&retain_phasic)/sum(retain_roi{i}&retain_pos);
    end

    %neg
    for i = 1:length(roiList); 
        [phasic_neg_p(i),phasic_neg_stats(i)] = ...
            counts_perm_local(groupData(retain_roi{i}&retain_neg),retain_phasic(retain_roi{i}&retain_neg),phasic_neg_frac_mean);
        phasic_neg_frac(i) = sum(retain_roi{i}&retain_neg&retain_phasic)/sum(retain_roi{i}&retain_neg);
    end
    
% tonic
    %pos
    for i = 1:length(roiList); 
        [tonic_pos_p(i),tonic_pos_stats(i)] = ...
            counts_perm_local(groupData(retain_roi{i}&retain_pos),retain_tonic(retain_roi{i}&retain_pos),tonic_pos_frac_mean);
        tonic_pos_frac(i) = sum(retain_roi{i}&retain_pos&retain_tonic)/sum(retain_roi{i}&retain_pos);
    end

    %neg
    for i = 1:length(roiList); 
        [tonic_neg_p(i),tonic_neg_stats(i)] = ...
            counts_perm_local(groupData(retain_roi{i}&retain_neg),retain_tonic(retain_roi{i}&retain_neg),tonic_neg_frac_mean);
        tonic_neg_frac(i) = sum(retain_roi{i}&retain_neg&retain_tonic)/sum(retain_roi{i}&retain_neg);
    end
    
% alfa thresh
alfa_thresh_pos = fdr([phasic_pos_p(regStruct.pos_reg) tonic_pos_p(regStruct.pos_reg)],config.alfa);
alfa_thresh_neg = fdr([phasic_neg_p(regStruct.neg_reg) tonic_neg_p(regStruct.neg_reg)],config.alfa);
if isempty(alfa_thresh_neg)
   alfa_thresh_neg = 0;
end
if isempty(alfa_thresh_pos)
    alfa_thresh_pos = 0;
end
% regStruct (region struct)
phasTonStruct.phasic_pos_ret = phasic_pos_p<=alfa_thresh_pos;
phasTonStruct.phasic_neg_ret = phasic_neg_p<=alfa_thresh_neg;
phasTonStruct.tonic_pos_ret =  tonic_pos_p<=alfa_thresh_pos;
phasTonStruct.tonic_neg_ret = tonic_neg_p<=alfa_thresh_neg;

phasTonStruct.phasic_pos_p = phasic_pos_p;
phasTonStruct.phasic_neg_p = phasic_neg_p;
phasTonStruct.tonic_pos_p =  tonic_pos_p;
phasTonStruct.tonic_neg_p = tonic_neg_p;

phasTonStruct.phasic_pos_frac = phasic_pos_frac;
phasTonStruct.phasic_neg_frac = phasic_neg_frac;
phasTonStruct.tonic_pos_frac =  tonic_pos_frac;
phasTonStruct.tonic_neg_frac = tonic_neg_frac;

phasTonStruct.phasic_pos_frac_mean = phasic_pos_frac_mean;
phasTonStruct.phasic_neg_frac_mean = phasic_neg_frac_mean;
phasTonStruct.tonic_pos_frac_mean =  tonic_pos_frac_mean;
phasTonStruct.tonic_neg_frac_mean = tonic_neg_frac_mean;

swagFig
bar([1 2],[phasic_pos_frac_mean phasic_neg_frac_mean;tonic_pos_frac_mean tonic_neg_frac_mean]',...
    'stacked')
swagAxes(gca,12,'Contact type','Fraction of electrodes')
legend('location','northeastoutside',{'Phasic', 'Tonic','Other'});
set(gca,'xlim',[.5 2.5])

swagFig([ 0.4504    0.7212    0.5598    0.2117]);
ret = regStruct.pos_reg;
bar([phasic_pos_frac(ret);tonic_pos_frac(ret)]','grouped')
set(gca,'xtick',1:sum(ret),'xticklabel',roiList(ret));
swagAxes(gca,12,'Region of interest','Fraction of electrodes')
legend('location','northeastoutside',{'Phasic', 'Tonic','Other'});

swagFig([ 0.4504    0.7212    0.5598    0.2117]);
ret = regStruct.neg_reg;
bar([phasic_neg_frac(ret);tonic_neg_frac(ret)]','grouped')
set(gca,'xtick',1:sum(ret),'xticklabel',roiList(ret));
swagAxes(gca,12,'Region of interest','Fraction of electrodes')
legend('location','northeastoutside',{'Phasic', 'Tonic','Other'});

function [] = make_timing_heatmap(groupData,config,powConfig)
[numElecs,retain_pos,...
        retain_neg,retain_posNeg,...
        retain_nsig] = idSig_local(groupData,config);
  
    pos_onset = [groupData(retain_pos).posClusOnset];
    neg_onset = [groupData(retain_neg).negClusOnset];
    onset = [pos_onset,neg_onset];
    
    pos_offset = [groupData(retain_pos).posClusOffset];
    neg_offset = [groupData(retain_neg).negClusOffset];    
    offset = [pos_offset,neg_offset];

    pos_dur = [groupData(retain_pos).posClusDur];
    neg_dur = [groupData(retain_neg).negClusDur];    
    dur = [pos_dur,neg_offset];
    
    % timing heat map
    timeBinSize = 100;
    timeBinStep = 10;
    timeBinDur = powConfig.postMS+powConfig.priorMS;
    t_ends=[timeBinSize:timeBinStep:timeBinDur]-powConfig.priorMS;
    t_starts = t_ends-timeBinSize+1;
    timeBins = [t_starts' t_ends'];
    t_lbl = mean(timeBins,2);
    timing_heatmap = nan(size(timeBins,1),size(timeBins,1));
    for t_on = 1:size(timeBins,1)
        for t_offset = 1:size(timeBins,1)
            
            onset_match = (onset<timeBins(t_on,2) & onset>=timeBins(t_on,1));
            offset_match = (offset<timeBins(t_offset,2) & offset>=timeBins(t_offset,1));

            numContacts = sum(onset_match&offset_match);
            timing_heatmap(t_offset,t_on) = numContacts;
                
        end
    end
    timing_heatmap(timing_heatmap<1) = nan;
    swagFig;
    imagescnan(timing_heatmap);
    set(gca,'ydir','normal','clim',[-15 15]); colorbar
    [~,zero_ind] = min(abs(t_lbl));  [~,end_ind] = min(abs(t_lbl-powConfig.postMS)); 
    xl = get(gca,'xlim');
    hold all;
    plot([xl(1):xl(2)],[xl(1):xl(2)],'linestyle','-','linewidth',3,'color','k')
    swagAxes(gca,12,'Onset (ms)','Offset (ms)')
    set(gca,'xlim',[zero_ind end_ind],'ylim',[zero_ind end_ind])
    xt = get(gca,'xtick');yt = get(gca,'ytick');
    set(gca,'xticklabel',t_lbl(xt),'yticklabel',t_lbl(yt))
    drawVertLine(gca,zero_ind)
    
function[chi2stat,p,df,obs_cat,obs_freq,expec_freq] = doChi2_local(groupData,config)
    alfa = config.alfa;
    %identify sig. contacts
    [numElecs,retain_pos,retain_neg,retain_posNeg,...
        retain_nsig] = idSig_local(groupData,config);
    
    % more sig than chance?
    obs_freq = [sum(~retain_nsig) sum(retain_nsig)];
    expec_freq = [alfa*numElecs (1-alfa)*numElecs];
    [chi2stat,p,df] = chi2test([obs_freq' expec_freq']);
    obs_cat = [sum(retain_pos) sum(retain_neg) sum(retain_posNeg) sum(retain_nsig)];
  
function[numElecs,retain_pos,retain_neg,retain_posNeg,retain_nsig] = idSig_local(groupData,config)
    alfa = config.alfa;
    numElecs = length(groupData);
    retain_pos = ([groupData.posClusP]<alfa)&isnan([groupData.negClusP]);
    retain_neg = ([groupData.negClusP]<alfa)&isnan([groupData.posClusP]);
    retain_posNeg = ([groupData.posClusP]<alfa)&([groupData.negClusP]<alfa);
    retain_nsig = ~retain_pos&~retain_neg&~retain_posNeg;

function [config] = getConfig_local(configNum)
dirs = ps2_dirs;

% alfa
config.alfa = 0.05;

%clus stats info
config.compar = 'fb_posNeg';
config.powConfigNum = 1;
config.fRange = [70 200];
config.diffLbl = 'posVneg';
config.clusStatsInfo_rootDir  = fullfile(dirs.analyses,...
    'ecog','subjPow','clusStats');
config.clusStatsInfo_dir = fullfile(config.clusStatsInfo_rootDir,config.compar,...
    ['powConfig' num2str(config.powConfigNum) '-' num2str(config.fRange(1)) '-' num2str(config.fRange(2))]);

% phasic and tonic thresh
config.onset_thresh = [0 1000];
config.offset_thresh = 1000;
config.duration_thresh = 750;

%min subj 
config.min_subj = 5;
%save dir 
config.saveDir = fullfile(dirs.analyses,'ecog','subjPow',...
    'analyses','clusPosNeg',[config.compar '-' num2str(config.powConfigNum) '-' num2str(config.fRange(1)) '-' num2str(config.fRange(2))]);

function [groupData,powConfig] = collect_local()
global CONFIGNUM
config = getConfig_local(CONFIGNUM);
[subjList] = ps2_ecog_subjPow_getSubjList;
cd_mkdir(config.saveDir);
saveFile = 'groupData.mat';

if exist(saveFile,'file')
    load(saveFile)
else
    groupData = struct;
    count = 0;
    sStart = 1;
    eStart = 1;
end
for s = sStart:length(subjList)
    [elecList] =  ps2_ecog_subjPow_getElecList(subjList(s).subj);

    % get behavioral stuff here
    [fbEvents] = ps2_ecog_subjPow_getSubjEv(subjList(s).subj);
    acc = mean([fbEvents.correct]);
   
    for e = eStart:length(elecList)
       if s == 1 && e == 1
            % load powConifg;
            [~,~,~,~,~,powConfig] = ...
            ps2_ecog_subjPow_getSubjPow(subjList(s).subj,elecList(e).eNames,config.powConfigNum);
       end

      count = count + 1;
      [compPowStruct] = ps2_ecog_subjPow_doComp(subjList(s).subj,elecList(e).eNames,...
          config.compar,config.powConfigNum,config.fRange);
      clusStats = compPowStruct.(config.diffLbl);

      % update structure
      groupData(count).subj = subjList(s).subj;
      groupData(count).eName = elecList(e).eNames;

      % beh
      groupData(count).acc = acc;

      %anat (currently uses snapped information). Stores anatomical labels
      %from each individual brain as well as those obtained from
      %registering the post-op ct to the group brain.
      bpTalStruct = getBipolarSubjElecs(elecList(e).subj_list{1},1);
      thisTal = [bpTalStruct.avgSurf]; indivTal = [bpTalStruct.indivSurf];
      thisName = regexp(elecList(e).eNames,'_','split');
      eStruct = bpTalStruct(strcmp({bpTalStruct.eNames},thisName{1}));
      eTal = thisTal(strcmp({bpTalStruct.eNames},thisName{1}));
      eTal_indiv = indivTal(strcmp({bpTalStruct.eNames},thisName{1}));
      
      % update
      groupData(count).xyz =  [eTal.x_snap eTal.y_snap eTal.z_snap];%elecList(e).xyz;
      groupData(count).anatRegion = eTal.anatRegion_snap;
      groupData(count).anatRegion_indiv = eTal_indiv.anatRegion_snap;
      groupData(count).distance_snap = eTal.distance_snap;
      
      if strcmp(eStruct.eType,'D') % update anatRegion based on depth label
        groupData(count).anatRegion = parseDepth_local(eStruct);
        groupData(count).anatRegion_indiv = groupData(count).anatRegion;
        groupData(count).distance_snap = eTal.distance_snap;
      end
      
      groupData(count).ROI = getROI_local(eTal,eStruct);
      groupData(count).eType = eStruct.eType;
      
      % t vec
      groupData(count).tVec = clusStats.tVec;

      % summary clus stats stuff
      if ~isempty(clusStats.posClusStats(1))&&clusStats.posClusStatsP(1)<config.alfa;
          groupData(count).posClusStat = clusStats.posClusStats(1);
          groupData(count).posClusP = clusStats.posClusStatsP(1);
          groupData(count).posClusOnset = clusStats.posClusInd{1}(1);
          groupData(count).posClusOffset = clusStats.posClusInd{1}(end);
          groupData(count).posClusDur = clusStats.posClusInd{1}(end)-clusStats.posClusInd{1}(1);
          clusIdx = ismember(powConfig.timeWins_lbl,clusStats.posClusInd{1});
          [groupData(count).posClusPeak,peakOnset]...
              = max(abs(clusStats.tVec(clusIdx)));
           groupData(count).posClusPeakOnset = clusStats.posClusInd{1}(peakOnset);
      else
          groupData(count).posClusStat = nan;
          groupData(count).posClusP = nan;
          groupData(count).posClusOnset = nan;
          groupData(count).posClusOffset = nan;
          groupData(count).posClusDur = nan;
          groupData(count).posClusPeak = nan;
          groupData(count).posClusPeakOnset = nan;
      end

      if ~isempty(clusStats.negClusStats(1))&&clusStats.negClusStatsP(1)<config.alfa;
          groupData(count).negClusStat = clusStats.negClusStats(1);
          groupData(count).negClusP = clusStats.negClusStatsP(1);
          groupData(count).negClusOnset = clusStats.negClusInd{1}(1);
          groupData(count).negClusOffset = clusStats.negClusInd{1}(end);
          groupData(count).negClusDur = clusStats.negClusInd{1}(end)-clusStats.negClusInd{1}(1);
                clusIdx = ismember(powConfig.timeWins_lbl,clusStats.negClusInd{1});
          [groupData(count).negClusPeak,peakOnset]...
              = max(abs(clusStats.tVec(clusIdx)));
          groupData(count).negClusPeakOnset = clusStats.negClusInd{1}(peakOnset);
      else
          groupData(count).negClusStat = nan;
          groupData(count).negClusP = nan;
          groupData(count).negClusOnset = nan;
          groupData(count).negClusOffset = nan;
          groupData(count).negClusDur = nan;
          groupData(count).negClusPeak = nan;
          groupData(count).negClusPeakOnset = nan;
      end
        %iteratively save
        cd(config.saveDir);
        eStart = e+1;
        if eStart>length(elecList)
            sStart = s+1;
            eStart = 1;
        end
        save(saveFile,'groupData','powConfig','count','sStart','eStart')
        disp(count);    
    end
end
function [anatRegion] = parseDepth_local(eStruct)
% get mtl leads
region_list = {'hipp','ec','amy','phc',...
    'prc','mtl','fusiform','itg','mtg','stg'};

lbl_list = {'hippocampus','entorhinal',...
    'amygdala','parahippocampal','parahippocampal',...
    'MTL','fusiform','inferiortemporal','middletemporal',...
    'superiortemporal'};

% combine regions
anatRegion = 'unknown';
for i = 1:length(region_list)
    [idx] = get_mtl_leads(eStruct(1).subject,region_list{i});
    if any(ismember(eStruct.channel,idx))
       anatRegion = lbl_list{i};
    end
end
function [ROI_list] = getROI_local(thisTal,bpTalStruct)
%keyboard
ROI_list = cell(1,length(thisTal));

% get mtl leads
[hippIdx,~,~,js_error] = get_mtl_leads(bpTalStruct(1).subject,'hipp');
phcIdx = get_mtl_leads(bpTalStruct(1).subject,'phc');
prcIdx = get_mtl_leads(bpTalStruct(1).subject,'prc');
ecIdx = get_mtl_leads(bpTalStruct(1).subject,'ec');
%mIdx = get_mtl_leads(bpTalStruct(1).subject,'mtl');
mtlIdx = unique([hippIdx;phcIdx;prcIdx;ecIdx]);

fusIdx = get_mtl_leads(bpTalStruct(1).subject,'fusiform');

itgIdx = get_mtl_leads(bpTalStruct(1).subject,'itg');
mtgIdx = get_mtl_leads(bpTalStruct(1).subject,'mtg');
stgIdx = get_mtl_leads(bpTalStruct(1).subject,'stg');
temp_idx = unique([itgIdx;mtgIdx;stgIdx]);
if js_error == 1
    disp([bpTalStruct(1).subject '...Joel stein not working'])
end

for i = 1:length(thisTal)
    switch bpTalStruct(i).eType
        case {'D'}
            if any(ismember(bpTalStruct(i).channel,mtlIdx))
                ROI_list{i} = 'MTL';
            elseif any(ismember(bpTalStruct(i).channel,fusIdx))
                ROI_list{i} = 'fusiform';
            elseif any(ismember(bpTalStruct(i).channel,temp_idx))
                ROI_list{i} = 'temporal';
            else
                ROI_list{i} = 'OTHER';
            end
        otherwise
            switch thisTal(i).anatRegion_snap
                % frontal pole,
                case {'medialorbitofrontal','lateralorbitofrontal'}
                    ROI_list{i} = 'orbitofrontal';
                case {'parsorbitalis','parstrianglularis','parsopercularis'}
                    ROI_list{i} = 'vlPFC';
                case {'caudalmiddlefrontal','rostralmiddlefrontal'}
                    ROI_list{i} = 'dlPFC';
                case {'superiorfrontal','rostralanteriorcingulate','caudalanteriorcingulate'}
                   ROI_list{i} = 'ant_front_med'; 
                case {'paracentral','posteriorcingulate','isthmuscingulate'}
                    ROI_list{i} = 'post_front_med';
                case {'precentral','postcentral'}
                    ROI_list{i} = 'sensorimotor';
                case {'superiorparietal','supramarginal','inferiorparietal'}
                    ROI_list{i} = 'parietal';
                case {'bankssts','inferiortemporal','middletemporal','superiortemporal','temporalpole','transversetemporal'}     
                    ROI_list{i} = 'temporal';
                case {'fusiform'}
                    ROI_list{i} = 'fusiform';
                case {'cuneus','lateraloccipital','lingual','pericalcarine'}
                     ROI_list{i} = 'occipital';
                case {'parahippocampal','entorhinal'}
                     ROI_list{i} = 'MTL';
                otherwise
                     ROI_list{i} = 'OTHER';
            end
     
    end
end



% OLD SUBFUNCTIONS - not in use currently
function [] = roi_avgResponses_local(xSubjFlag,groupData,powConfig,config,roiList,retain_roi)
[numElecs,retain_pos,...
        retain_neg,retain_posNeg,...
        retain_nsig] = idSig_local(groupData,config);
%swagFig([0.7504    0.0057    0.1387    0.9455]);
%yL = [-4 4];
for r = 1:length(roiList)
    %subplot(length(roiList),1,r)
    swagFig;
    
    if xSubjFlag
        [groupData_subj] = collapse_w_subj(groupData,retain_roi{r});
    else
        groupData_subj = groupData(retain_roi{r});
    end
    
    
    if ~isempty(fieldnames(groupData_subj));
        tVec = cat(1,groupData_subj.tVec);
        plotSEM(powConfig.timeWins_lbl,nanmean(tVec,1),SEM(tVec),[.6 .6 .6]);
    end
%     hold all
%     [groupData_subj] = collapse_w_subj(groupData,retain_roi{r}&retain_pos);
%     if ~isempty(fieldnames(groupData_subj));
%         tVec = cat(1,groupData_subj.tVec);
%         plotSEM(powConfig.timeWins_lbl,nanmean(tVec,1),SEM(tVec),[.6 1 .6]);
%     end
%     hold all
%     [groupData_subj] = collapse_w_subj(groupData,retain_roi{r}&retain_neg);
%     if ~isempty(fieldnames(groupData_subj));
%         tVec = cat(1,groupData_subj.tVec);
%         plotSEM(powConfig.timeWins_lbl,nanmean(tVec,1),SEM(tVec),[1 .6 .6]);    
%     end
    swagAxes(gca,12,'Time from feedback (ms)','t-statistic (pos - neg)',roiList{r})
    %set(gca,'ylim',yL)
    [~,zero_ind] = min(abs(powConfig.timeWins_lbl-0));
    drawVertLine(gca,zero_ind)
end

function [] = roi_onsetDur_local(xSubjFlag,groupData,powConfig,config,roiList,retain_roi)
[numElecs,retain_pos,...
        retain_neg,retain_posNeg,...
        retain_nsig] = idSig_local(groupData,config);
h(1) = swagFig([0.5523    0.7199    0.4008    0.2313]);hold all
%h(2) = swagFig([0.5523    0.7199    0.4008    0.2313]);hold all

cList = jet(length(roiList));
for r = 1:length(roiList)
    if xSubjFlag == 1
        [groupData_subj] = collapse_w_subj(groupData,retain_roi{r}&retain_pos);
    else
        groupData_subj = groupData(retain_roi{r}&retain_pos);
    end
    if ~isempty(fieldnames(groupData_subj))&&~isempty(groupData_subj)
        onset = [groupData_subj.posClusOnset]; offset = [groupData_subj.posClusDur];
        figure(h(1))
%         subplot(1,2,1);hold all
%         errorbar(r, mean(onset), SEM(onset'),'.k','linewidth',3)
%         
%         figure(h(2))
%         subplot(1,2,1);hold all
%         errorbar(r, mean(offset), SEM(offset'),'.k','linewidth',3)

        subplot(1,2,1);hold all
        [x,y] = errorEllipse(mean(onset),mean(offset),SEM(onset'),SEM(offset'),[],[.2 .2 .2]);
            swagAxes(gca,12,'Onset (ms)','Duration (ms)','',1)
        text(x,y,roiList{r})
    end
        
    if xSubjFlag == 1
        [groupData_subj] = collapse_w_subj(groupData,retain_roi{r}&retain_neg);
    else
        groupData_subj = groupData(retain_roi{r}&retain_neg);
    end
    
    if ~isempty(fieldnames(groupData_subj))&&~isempty(groupData_subj)
        onset = [groupData_subj.negClusOnset]; offset = [groupData_subj.negClusDur];
        
        figure(h(1))
%        subplot(1,2,2);hold all
%         errorbar(r, mean(onset), SEM(onset'),'.k','linewidth',3)
%         
%         figure(h(2))
%         subplot(1,2,2);hold all
%         errorbar(r, mean(offset), SEM(offset'),'.k','linewidth',3)

        
        subplot(1,2,2);hold all
        [x,y] = errorEllipse(mean(onset),mean(offset),SEM(onset'),SEM(offset'),[],[.2 .2 .2]);
           swagAxes(gca,12,'Onset (ms)','Duration (ms)','',1);
        text(x,y,roiList{r})
    end
      
end
function[behStats] = behStats_local(uSubj,events,fb_pair_lbl,pair_list)
correct = [events.correct];
button = [events.button];
for p = 1:length(pair_list)
    pairIdx = strcmp(pair_list{p},fb_pair_lbl);
    
    % early idx
    early_idx = false(size(pairIdx));
    early_idx(find(pairIdx,10,'first')) = true;
  
    fb = [events.fb]==1; %reward trials
    fb_lag1 = circshift(fb,[0 1]); %trials after wins (1) or losses (0)
    samePair_lag1 = [0 (diff(pairIdx))==0]; %trials where pair was same as prev trial
    sameItem_lag1 = [0 (diff(correct))==0]; %trials where the item choice was same as prev trial
    sameButton_lag1 = [0 (diff(button))==0]; %trials where the button choice was same as prev trial

    % pair number 
    thisStats(p).pairNum = unique([events(pairIdx).pairNum]);
    
    %num trials
    thisStats(p).numTrials = sum(pairIdx);
    
    %pair-wise acc
    thisStats(p).acc = mean(correct(pairIdx));
     
    % acc_01 (accuracy on first 10 trials)
    thisStats(p).acc01 = mean(correct(find(pairIdx,10,'first'))); 
    
    % acc_10 (accuracy on last 10 trials)
    thisStats(p).acc10 = mean(correct(find(pairIdx,10,'last'))); 

    % win-lag1: behavior on (AB) trials following reward where the same pair
    % was available. Only during the first 10 trials
    retain = pairIdx&fb_lag1&samePair_lag1&early_idx;
    thisStats(p).winStay = mean(sameItem_lag1(retain)); %win-same item
    thisStats(p).winSameButton = mean(sameButton_lag1(retain)); %win-same button
    thisStats(p).winStayZ = mean(sameItem_lag1(retain)) - mean(sameItem_lag1(pairIdx&~fb_lag1&samePair_lag1)); %win-same item - lose same item
    
    % lose-lag1: behavior on (AB) trials following loss trials where the same pair 
    % was available. Only during the first 10 trials
    retain = pairIdx&~fb_lag1&samePair_lag1&early_idx;
    thisStats(p).loseSwitch = mean(~sameItem_lag1(retain)); %lose-switch
    thisStats(p).loseSwitchButton = mean(~sameButton_lag1(retain)); %win-switch button
end
behStats = struct;
behStats.uSubj = uSubj;
names = fieldnames(thisStats); 
for n = 1:length(names)
   behStats.(names{n}) = nanmean([thisStats.(names{n})]); 
end
   