function [] = ps2_ecog_subjPow_anal_posNeg_plotEg(configNum,retLbl,compar)
% This function plots e.g., responses using information collected in
% anal_posNeg.

% load groupdata
[groupData,powConfig,config,statsStruct,retStruct,catLbls] = ...
    ps2_ecog_subjPow_anal_posNeg_selectivity(configNum,retLbl,compar,0);

% make plot
switch compar
    case 'fb_posNeg'
        plot_posNeg_local(groupData,compar,powConfig,config)
    case 'fb_pairWise';
        plot_pairWise_local(groupData,compar,powConfig,config)
    case 'fb_RPE_LRN'
        groupData = groupData(catLbls.pos.negT&retStruct.retain_pos);
        plot_RPE_local(groupData,compar,powConfig,config)
end

%%% FUNCTIONS %%%

function [dirs] = getDirs_local(compar);
d = ps2_dirs;
dirs.figDir = fullfile(d.fig.analyses,'ecog','subjPow','posNeg_eg',compar);


function [] = plot_posNeg_local(groupData,compar,powConfig,config)
[~,zeroInd] = min(abs(powConfig.timeWins_lbl));
lbl = {'fb_pos','fb_neg'};
kol = [.6 1 .6;1 .6 .6];
[dirs] = getDirs_local(compar);
for i = 1:length(groupData)
    
    % go to compar directory
    cd(config.clusStatsInfo_dir)
    fname = [groupData(i).subj '-' groupData(i).eName];
    load(fname)
    
    swagFig;hold all
    for j = 1:length(lbl)
        plot_local(compPowStruct,lbl{j},kol(j,:))
    end
    
    swagAxes(gca,12,'Time from feedback onset (ms)',['z Power '...
        num2str(config.fRange(1)) '-' num2str(config.fRange(2))],...
        [fname '-' groupData(i).anatRegion]);
    xt = get(gca,'xtick');
    set(gca,'xticklabel',powConfig.timeWins_lbl(xt));
    drawVertLine(gca,zeroInd);
    
    disp(i);
   
    cd_mkdir(dirs.figDir);
    print(gcf,fname,'-dpng','-r150'); close 
   
end


function [] = plot_pairWise_local(groupData,compar,powConfig,config)
[~,zeroInd] = min(abs(powConfig.timeWins_lbl));
lbl1 = {'fb_pos_AB','fb_pos_CD','fb_pos_EF'};
kol1 = [.8 1 .8;.4 1 .4;0 1 0];
lbl2 = {'fb_neg_AB','fb_neg_CD','fb_neg_EF'};
kol2 = [1 .8 .8;1 .4 .4;1 0 0];
[dirs] = getDirs_local(compar);
compar_dir =  fullfile(config.clusStatsInfo_rootDir,compar,...
    ['powConfig' num2str(config.powConfigNum) '-' num2str(config.fRange(1)) '-' num2str(config.fRange(2))]);


for i = 1:length(groupData)
    
    % go to compar directory
    cd(compar_dir)
    fname = [groupData(i).subj '-' groupData(i).eName];
    load(fname)
    
    swagFig([0.5836    0.7072    0.3859    0.1952]);
    subplot(1,2,1); hold all
    for j = 1:length(lbl1)
        plot_local(compPowStruct,lbl1{j},kol1(j,:))
    end
    swagAxes(gca,12,'Time from feedback onset (ms)',['z Power '...
        num2str(config.fRange(1)) '-' num2str(config.fRange(2))],...
        [fname '-' groupData(i).anatRegion]);
    yl = get(gca,'ylim');
    xt = get(gca,'xtick');
    set(gca,'xticklabel',powConfig.timeWins_lbl(xt));

    subplot(1,2,2); hold all
    for j = 1:length(lbl2)
        plot_local(compPowStruct,lbl2{j},kol2(j,:))
    end
    swagAxes(gca,12,'Time from feedback onset (ms)',['z Power '...
    num2str(config.fRange(1)) '-' num2str(config.fRange(2))],...
    [fname '-' groupData(i).anatRegion]);
    yl = [yl get(gca,'ylim')];
    xt = get(gca,'xtick');
    set(gca,'xticklabel',powConfig.timeWins_lbl(xt));

    
    subplot(1,2,1); set(gca,'ylim',[min(yl) max(yl)]);drawVertLine(gca,zeroInd);
    subplot(1,2,2); set(gca,'ylim',[min(yl) max(yl)]);drawVertLine(gca,zeroInd);
    
    disp(i);
   
    cd_mkdir(dirs.figDir);
    print(gcf,fname,'-dpng','-r150'); close 
   
end

function [] = plot_RPE_local(groupData,compar,powConfig,config,dirLbl)
if ~exist('dirLbl','var') || isempty(dirLbl)
    dirLbl = compar;
end
[~,zeroInd] = min(abs(powConfig.timeWins_lbl));
lbl1 = {'fb_pos_loExp','fb_pos_medExp','fb_pos_hiExp'};
kol1 = [.8 1 .8;.4 1 .4;0 1 0];
lbl2 = {'fb_neg_loExp','fb_neg_medExp','fb_neg_hiExp'};
kol2 = [1 .8 .8;1 .4 .4;1 0 0];
[dirs] = getDirs_local(dirLbl);
compar_dir =  fullfile(config.clusStatsInfo_rootDir,compar,...
    ['powConfig' num2str(config.powConfigNum) '-' num2str(config.fRange(1)) '-' num2str(config.fRange(2))]);


for i = 1:length(groupData)
     
    % get file name
    fname = [groupData(i).subj '-' groupData(i).eName];
    
    % go to compar directory
    cd(config.clusStatsInfo_dir)
    
    % load file name
    load(fname)
    
    clusStats = compPowStruct.posVneg;
    
    pos_ind = []; neg_ind = [];
    if ~isempty(clusStats.posClusStatsP)
        pos_ind = clusStats.posClusInd{1};
    end
    if ~isempty(clusStats.negClusStatsP)
        neg_ind = clusStats.negClusInd{1};
    end
    if length(pos_ind)>length(neg_ind)
        t_ind = pos_ind;
    else
        t_ind = neg_ind;
    end
    
    % go to compar directory
    cd(compar_dir)
    load(fname)
    
    swagFig([ 0.5836    0.4715    0.3547    0.4309]);
    subplot(2,2,1); hold all
    for j = 1:length(lbl1)
        plot_local(compPowStruct,lbl1{j},kol1(j,:))
    end
    swagAxes(gca,12,'Time from feedback onset (ms)',['z Power '...
        num2str(config.fRange(1)) '-' num2str(config.fRange(2))],...
        [fname '-' groupData(i).anatRegion]);
    yl = get(gca,'ylim');
    xt = get(gca,'xtick');
    set(gca,'xticklabel',powConfig.timeWins_lbl(xt));

    subplot(2,2,2); hold all
    for j = 1:length(lbl2)
        plot_local(compPowStruct,lbl2{j},kol2(j,:))
    end
    swagAxes(gca,12,'Time from feedback onset (ms)',['z Power '...
    num2str(config.fRange(1)) '-' num2str(config.fRange(2))],...
    [fname '-' groupData(i).anatRegion]);
    yl = [yl get(gca,'ylim')];
    xt = get(gca,'xtick');
    set(gca,'xticklabel',powConfig.timeWins_lbl(xt));

    subplot(2,2,3); hold all
    for j = 1:length(lbl1)
        plot_local(compPowStruct,lbl1{j},kol1(j,:),t_ind,powConfig,j)
    end
    swagAxes(gca,12,'Time from feedback onset (ms)',['z Power '...
        num2str(config.fRange(1)) '-' num2str(config.fRange(2))],...
        [fname '-' groupData(i).anatRegion]);
    set(gca,'xtick',1:length(lbl1),'xticklabel',lbl1);
    set(gca,'xlim',[.5 length(lbl1)+.5])
    subplot(2,2,4); hold all
    for j = 1:length(lbl2)
        plot_local(compPowStruct,lbl2{j},kol1(j,:),t_ind,powConfig,j)
    end
    swagAxes(gca,12,'Time from feedback onset (ms)',['z Power '...
        num2str(config.fRange(1)) '-' num2str(config.fRange(2))],...
        [fname '-' groupData(i).anatRegion]);
    set(gca,'xtick',1:length(lbl1),'xticklabel',lbl1);
    set(gca,'xlim',[.5 length(lbl2)+.5])
    subplot(2,2,1); set(gca,'ylim',[min(yl) max(yl)]);drawVertLine(gca,zeroInd);
    subplot(2,2,2); set(gca,'ylim',[min(yl) max(yl)]);drawVertLine(gca,zeroInd);
    
    disp(i);
   
    cd_mkdir(dirs.figDir);
    print(gcf,fname,'-depsc2','-r150'); close 
   
end

function[] = plot_local(compPowStruct,lbl,kol,t_ind,powConfig,i)
if ~exist('t_ind','var') || isempty(t_ind)
plotSEM(1:size(compPowStruct.(lbl),2),...
    nanmean(compPowStruct.(lbl),1),SEM(compPowStruct.(lbl)),kol);
plot(1:size(compPowStruct.(lbl),2),...
    nanmean(compPowStruct.(lbl),1),'k','linewidth',3);
else
    [rate,rate_vec] = getRate_local(compPowStruct,lbl,t_ind,powConfig);
    
    errorbar(i,nanmean(rate),SEM(rate),'k','linewidth',3);hold all
    bar(i,nanmean(rate),'facecolor',[.6 .6 .6]);
end
    
function[rate,rate_vec] = getRate_local(compPowStruct,lbl,t_ind,powConfig)
rate_vec = compPowStruct.(lbl);
rate = nanmean(rate_vec(:,ismember(powConfig.timeWins_lbl,t_ind)),2);
