function [groupData,powConfig,config,statsStruct,retStruct,catLbls] = ...
    ps2_ecog_subjPow_anal_posNeg_selectivity(configNum,retLbl,compar,plotFlag)
% This function performs selectivity analyses based on contacts identified
% in  anal_posNeg. Uses sig. time windows identified in pos_neg analyses,
% or another time interval of interest.

% load groupdata - all electodes for a given comparison
[groupData,config,powConfig,retStruct] = ps2_ecog_subjPow_anal_posNeg(configNum,0);

% apply retain to select a subgroup of electrodes
if exist('retLbl','var') && ~isempty(retLbl)
    switch retLbl
        case 'posOrNeg'
            groupData = groupData(retStruct.retain_pos|retStruct.retain_neg); 
        otherwise
            groupData = groupData(retStruct.(retLbl));
    end
end

% collect sig. stats. For each electrode, it computes statistics on a
% selected time interval of interest.
switch compar
    case 'fb_pairWise';
        lbl_pos= {'fb_pos_AB','fb_pos_CD','fb_pos_EF'}; 
        lbl_neg = {'fb_neg_AB','fb_neg_CD','fb_neg_EF'};
        [statsStruct] = ...
            pairWise_local(groupData,retLbl,compar,powConfig,config,lbl_pos,lbl_neg);
    case 'fb_RPE_LRN'
        lbl_pos= {'fb_pos_loExp','fb_pos_medExp','fb_pos_hiExp'}; 
        lbl_neg = {'fb_neg_loExp','fb_neg_medExp','fb_neg_hiExp'};
        [statsStruct] = ...
            pairWise_local(groupData,retLbl,compar,powConfig,config,lbl_pos,lbl_neg);
    case 'fb_RPE_train'
        lbl_pos= {'fb_pos_loExp','fb_pos_medExp','fb_pos_hiExp'}; 
        lbl_neg = {'fb_neg_loExp','fb_neg_medExp','fb_neg_hiExp'};
        [statsStruct] = ...
            pairWise_local(groupData,retLbl,compar,powConfig,config,lbl_pos,lbl_neg);
    case 'fb_earlyLate';
        lbl_pos = {'fb_pos_early','fb_pos_late'};
        lbl_neg = {'fb_neg_early','fb_neg_late'};
                [statsStruct] = ...
            pairWise_local(groupData,retLbl,compar,powConfig,config,lbl_pos,lbl_neg);
end

% rm contacts that don't have any data in the statsStruct
retain = ~isnan([statsStruct.pos_tBeta]);
groupData = groupData(retain);
statsStruct = statsStruct(retain);

% update anat regions
%[groupData] = upAnat_local(groupData);

% new retain structure 
[retStruct] = getRetStruct_local(groupData,config);

%%% How frequent are sig. contacts?
% generates labels based on the direction of regression effects (catLbls)
% generate three plots:
% 1) of all valence-encoding contacts, what is the direction of the
% regression effect following positive feedback, and following negative
% feedback?
% 2) of all pos > neg valence contacts, what is the freq. of pos, neg and
% non sig regression effects following positive and negative feedback
% 3) of all neg > pos valence contacts, what is the freq. of pos, neg and
% non sig regression effects following positive and negative feedback
[catLbls,catList_pos,catList_neg] = ...
    doCounts_local(statsStruct,config,retStruct,plotFlag);

% sigCounts_local
%Does an across subject counts analysis (using counts_perm_local) for the 
%following groups of valence encoding contacts 
%pos-posT - positive relation with reward expectation (‘posT’) 
%during positive feedback trials (pos). Also pos-negT, pos-nsig, neg-posT,
%neg-negT, and neg-nsig
[lbl_list,ps,stats] = sigCounts_local(groupData,catLbls,catList_pos,catList_neg,retStruct,config);

if plotFlag == 1
    cL = [-5 5];p= [];
    
    % do a battery of analyses for several particular groups of electrodes.
    % fbFlag = 1 indicates effects assoc with positive feedback trials.
    % posNegFlag = 3 indicates 
    %1) across subj correlation between the strength of a particular
    %regression effect and accuracy
    %2)average power for the following conditions: 
    % high, medium, low expectation x pos/neg feedback 
    
    % unexpected reward (UR) elecs:
    % pos_negT (pos contacts showing a negative relation with rew exp; 
    % unexpect rewards)
    ret1 = catLbls.pos.negT;
    fbFlag = 1; posNegFlag = 3;
    [r,p(end+1),x1,y1] = xSubjCorr(ret1,fbFlag,groupData,statsStruct);
    [vecs,lbls] = retain_wrapper(groupData,statsStruct,ret1,fbFlag,posNegFlag,lbl_pos,lbl_neg,powConfig,retStruct,config,cL);

    % unexpected penalty (UP) electrodes:
    % pos_negT (neg contacts)
    ret2 = catLbls.neg.posT;
    fbFlag = 2; posNegFlag = 3;
    [r,p(end+1),x2,y2] = xSubjCorr(ret2,fbFlag,groupData,statsStruct);
    [vecs,lbls] = retain_wrapper(groupData,statsStruct,ret2,fbFlag,posNegFlag,lbl_pos,lbl_neg,powConfig,retStruct,config,cL);
 
    % Anatomical analyses:
    % All valence-encoding electrodes
    swagFig([0.1848    0.0982    0.5570    0.2668]);
    ret = ~catLbls.pos.nsig|~catLbls.neg.non_sig;%&catLbls.neg.non_sig;%&~catLbls.neg.posT;
    expAlfa = 0.1;%expected freq of a significant effect following positive OR neg feedback
    roi_doCounts_local(groupData,ret,expAlfa,config,retStruct,posNegFlag,'r');
    set(gca,'ylim',[0 .6])
    plot(get(gca,'xlim'),[expAlfa expAlfa],'--k')
    
    %overall putative RPE greater than chance?
    [p,stats,num_sig_z] = counts_perm_local(groupData,ret,expAlfa,1);

    % freq of RPEs on left vs. right
    xyz = cat(1,groupData.xyz);
    lInd = xyz(:,1)<0;
    [p,stats,num_sig_z1,num_sig_z2] = ...
        counts2_perm_local(groupData(lInd),ret(lInd),expAlfa,groupData(~lInd),ret(~lInd),expAlfa,1);
    
    % Anatomical analysis for UR contacts
    swagFig([0.1848    0.0982    0.5570    0.2668]);
    ret = catLbls.pos.negT;
    expAlfa = .025; % expect freq of a sig. regression effect in a specific dir
    roi_doCounts_local(groupData,ret,expAlfa,config,retStruct,posNegFlag,'r');
    set(gca,'ylim',[0 .6])
    plot(get(gca,'xlim'),[expAlfa expAlfa],'--k')
    
    % Anatomical analysis for UP contacts
    swagFig([0.1848    0.0982    0.5570    0.2668]);
    ret = catLbls.neg.posT;% expect freq of a sig. regression effect in a specific dir
    expAlfa = 0.025;
    roi_doCounts_local(groupData,ret,expAlfa,config,retStruct,posNegFlag,'r');
    set(gca,'ylim',[0 .6])
    plot(get(gca,'xlim'),[expAlfa expAlfa],'--k')
    
    % Comparing frequencies of expected and unexpected reward contacts,
    % and of unexpected and expected penalty contacts
    % pos vs. neg relation with rew exp
    [p,stats,num_sig_z1,num_sig_z2] = ...
        counts2_perm_local(groupData,catLbls.pos.negT,0.025,groupData,catLbls.pos.posT,0.025,1);
    [p,stats,num_sig_z1,num_sig_z2] = ...
        counts2_perm_local(groupData,catLbls.neg.posT,0.025,groupData,catLbls.neg.negT,0.025,1);
end
    
% old analyses:
%     % plot pos v. neg counts
%     swagFig;subplot(1,2,1)
%     frac_pos(1) = sum(retStruct.retain_pos&ret1)/sum(ret1);
%     frac_neg(1) = sum(retStruct.retain_neg&ret1)/sum(ret1);
%     pie([frac_pos(1) frac_neg(1)])
%     subplot(1,2,2)
%     frac_pos(2) = sum(retStruct.retain_pos&ret2)/sum(ret2);
%     frac_neg(2) = sum(retStruct.retain_neg&ret2)/sum(ret2);
%     pie([frac_pos(2) frac_neg(2)])
%     bar([frac_pos; frac_neg]','stacked')
% 
%     thisRet = ret1|ret2;
%     alfa = sum(retStruct.retain_neg&~thisRet)/sum(~thisRet);
%     [p,stats] = counts_perm_local...
%         (groupData(thisRet),retStruct.retain_neg(thisRet),alfa,1);
%    
%     % Timing issues
%     % positive contacts
%     swagFig; hold all
%     [o_lrn,dur_lrn] = onsetDur_local(3,groupData,statsStruct,ret1,[.9 .5 .1]);
%     %ret = ~(ret1|ret2);%catLbls.pos.nsig& catLbls.neg.non_sig;
%     [o_nlrn,dur_nlrn] = onsetDur_local(3,groupData,statsStruct,ret2,[.6 .6 .6]);

%     [o_lrn2,dur_lrn2] =  onsetDur_local(3,groupData,statsStruct,ret2,[.9 .5 .5]);
%     set(gca,'xlim',[400 900],'ylim',[300 600])
    
%     % plot on brain
%     % get ind
%     xyz = cat(1,groupData.xyz);
%     lInd = xyz(:,1)<0;
%     
%     % plot pos
%     
%     % plot neg
%     [h_L,h_R,h_D] = ps2_ecog_subjPow_anal_posNeg_plotCountsOnBrain(1,[0 2000],1,'negHot',0,0);
%     figure(h_L); hold all
%     plot3_wrapper(xyz(lInd&ret2',:),20,'r')
%     figure(h_R); hold all
%     plot3_wrapper(xyz(~lInd&ret2',:),20,'r')


%%% FUNCTIONS %%%

function[groupData] = upAnat_local(groupData)
xyz = cat(1,groupData.xyz);
for i = 1:length(groupData);
    if xyz(i,1)<=0
        groupData(i).anatRegion = ['L_' groupData(i).anatRegion];
        groupData(i).ROI = ['L_' groupData(i).ROI{1}]; groupData(i).ROI = {groupData(i).ROI};
    else
        groupData(i).anatRegion = ['R_' groupData(i).anatRegion];
        groupData(i).ROI = ['R_' groupData(i).ROI{1}];groupData(i).ROI = {groupData(i).ROI};
    end
end
function [lbl_list,ps,stats] = sigCounts_local(groupData,catLbls,catList_pos,catList_neg,retStruct,config)
%initialize variables
ps =[];stats = struct('tstat',[],'df',[],'sd',[]);

% deal with positive fb trial effects first
catList =catList_pos; lbl ='pos';lbl_list = {};
% loop through the labels for the various regression effects (posT, negT, nsig)
for c = 1:length(catList) 
    ret = catLbls.(lbl).(catList{c});
    % run xsubj counts analysis. The reason that were using alfa/2 (0.025) 
    % is because the expected freq. of observing a sig. positive effect or
    % a sig. neg effect is 0.025. The expec freq of observing a sig effect
    % in any direction is 0.05.  
    [ps(end+1),stats(end+1),z] = counts_perm_local(groupData(retStruct.retain_pos|retStruct.retain_neg),...
        ret(retStruct.retain_pos|retStruct.retain_neg),config.alfa/2,1);
    lbl_list{end+1} = ['posOrNegContacts-' lbl '-' catList{c}];

%  If you want to seperately analyze positive and neegative feedback, edit
%  this bit "groupData(retStruct.retain_pos|retStruct.retain_neg),"
end

catList =catList_neg; lbl ='neg';
for c = 1:length(catList)
    ret = catLbls.(lbl).(catList{c});
    [ps(end+1),stats(end+1),z] = counts_perm_local(groupData(retStruct.retain_pos|retStruct.retain_neg),...
        ret(retStruct.retain_pos|retStruct.retain_neg),config.alfa/2,1);
    lbl_list{end+1} = ['posOrNegContacts-' lbl '-' catList{c}];
end

% rem first stats
stats(1) = [];

%filt by sig
ret = ps<=fdr(ps,0.05)&[stats.tstat]>0;
lbl_list(~ret) = [];
ps(~ret) = [];
stats(~ret) = [];


%    obs = [sum(retStruct.retain_pos&catLbls.(lbl).(catList{c})) sum(retStruct.retain_pos&~catLbls.(lbl).(catList{c}))];
%    expec = [config.alfa*sum(retStruct.retain_pos) (1-config.alfa)*sum(retStruct.retain_pos)];
%    [chi2stat,ps(end+1)] = chi2test([obs',expec']);
% 
%    obs = [sum(retStruct.retain_neg&catLbls.(lbl).(catList{c})) sum(retStruct.retain_neg&~catLbls.(lbl).(catList{c}))];
%    expec = [config.alfa*sum(retStruct.retain_neg) (1-config.alfa)*sum(retStruct.retain_neg)];
%    [chi2stat,ps(end+1)] = chi2test([obs',expec']);
% if ps(end) <config.alfa && stats.tstat>0%obs(1) > expec(1)
%    posRetain(1,c) = true;
% end   
% if ps(end) <config.alfa  && stats.tstat>0 %&& obs(1) > expec(1)
%        negRetain(1,c) = true;
% end


function[p,stats,num_sig_z] = counts_perm_local(groupData,retain,alfa,min_elecs);
subj_list  =unique({groupData.subj});
iters = 10000;
if ~exist('min_elecs','var')||isempty(min_elecs)
    min_elecs = 1;
end
for s = 1:length(subj_list)
   subj_ret =  strcmp({groupData.subj},subj_list{s});
   num_elecs(s) = sum(subj_ret);
   num_sig = sum(subj_ret&retain);
   
   % simulate null distribution for this subject
   num_sig_null = binornd(num_elecs(end),alfa,[1 iters]);
      
   % z-score by binomial dist
   num_sig_z(s) = (num_sig - mean(num_sig_null))/std(num_sig_null);
end
ret = num_elecs>=min_elecs;
[~,p,~,stats] = ttest(num_sig_z(ret));

function[p,stats,num_sig_z1,num_sig_z2] = counts2_perm_local(groupData,retain,alfa1,groupData2,retain2,alfa2,min_elecs);
subj_list  =unique([{groupData.subj} {groupData2.subj}]);
iters = 10000;
for s = 1:length(subj_list)
   subj_ret =  strcmp({groupData.subj},subj_list{s});
   num_elecs1(s) = sum(subj_ret);
   num_sig1 = sum(subj_ret&retain);
   num_sig_null = binornd(num_elecs1(end),alfa1,[1 iters]);
   num_sig_z1(s) = (num_sig1 - mean(num_sig_null))/std(num_sig_null);

   subj_ret =  strcmp({groupData2.subj},subj_list{s});
   num_elecs2(s) = sum(subj_ret);
   num_sig2 = sum(subj_ret&retain2);
   num_sig_null = binornd(num_elecs2(end),alfa2,[1 iters]);
   num_sig_z2(s) = (num_sig2 - mean(num_sig_null))/std(num_sig_null);
   %num_sig_null = binornd(num_elecs1(end),max([num_sig2/num_elecs2(end) min_alfa]),[1 iters]);
   %num_sig_z(s) = (num_sig1 - mean(num_sig_null))/std(num_sig_null);
   
end
ret = num_elecs1>=min_elecs & num_elecs2>=min_elecs;
[~,p,~,stats] = ttest(num_sig_z1(ret),num_sig_z2(ret));

function[vecs,lbls] = retain_wrapper(groupData,statsStruct,ret,fbFlag,posNegFlag,lbl_pos,lbl_neg,powConfig,retStruct,config,cL)
[vecs,lbls] = avgT_wrapper(1,groupData,...
    statsStruct,ret,lbl_pos,lbl_neg,powConfig);
make_timing_heatmap(statsStruct(ret),config,powConfig,cL,'o')
%swagFig([0.1848    0.0982    0.5570    0.2668]);
%roi_doCounts_local(groupData,ret,config,retStruct,posNegFlag);
%set(gca,'ylim',[0 .7])
xSubjCorr(ret,fbFlag,groupData,statsStruct);
xSubjCorr_fb(ret,posNegFlag,groupData,statsStruct);

%xSubjReg(ret,fbFlag,groupData,statsStruct);

%xSubjCorr_posNeg(ret,groupData,statsStruct)
function [onset,offset] = onsetDur_local(posNegFlag,groupData,statsStruct,ret1,kol)
%swagFig;hold all
[groupData1] = collapse_w_subj(groupData(ret1),statsStruct(ret1));
if posNegFlag == 1
    onset = [groupData1.posClusPeakOnset]; offset = [groupData1.posClusDur];
elseif posNegFlag == 2
    onset = [groupData1.negClusPeakOnset]; offset = [groupData1.negClusDur];
elseif posNegFlag == 3
    onset = nanmean([[groupData1.posClusPeakOnset]' [groupData1.negClusPeakOnset]'],2); 
    offset = nanmean([[groupData1.posClusDur]' [groupData1.negClusDur]'],2); 
end
error_ellipse(cov(onset',offset'),[mean(onset),mean(offset)])
swagAxes(gca,12,'Onset (ms)','Duration (ms)','',1)
    
function[roiList] =roi_doCounts_local(groupData,retain,expAlfa,config,retStruct,posNegFlag,kol)
roiList = retStruct.roiList;
retain_roi = retStruct.retain_roi;
if posNegFlag == 1
    tot_retain = retStruct.retain_pos;
elseif posNegFlag == 2;
    tot_retain = retStruct.retain_neg;
elseif posNegFlag == 3
    tot_retain = retStruct.retain_pos|retStruct.retain_neg;
end

%plot - fraction of pos and neg electrodes in each region
roi_counts = [];
for i = 1:length(roiList); 
    ret = retain_roi{i}&tot_retain;
    num_contacts(i) = sum(ret); num_subj(i) = length(unique({groupData(ret).subj}));
    if sum(ret)>0 && length(unique({groupData(ret).subj}))>=5
        [p_roi(i),stats(i),z] = counts_perm_local(groupData(ret),retain(ret),expAlfa,1);
        roi_counts(i) = sum(retain&ret)/sum(ret);
    else
        p_roi(i) = nan;
        stats(i) = struct('tstat',[],'df',[],'sd',[]);
        roi_counts(i) = 0;
    end
    %obs = [sum(retain&retain_roi{i}) sum(~retain&reg_tot_ret)];
    %exp = [sum(reg_tot_ret)*config.alfa sum(reg_tot_ret)*(1-config.alfa)];
    %[chi2stat_roi(i),p_roi(i)] = chi2test([obs;exp]);
end

alfa_thresh = fdr(p_roi(~isnan(p_roi)),config.alfa);%config.alfa;%
if isempty(alfa_thresh)||~any(p_roi<=alfa_thresh & roi_counts>expAlfa)
  alfa_thresh = 0;
  disp('No FDR survivors...')
end
%alfa_thresh = config.alfa;
%bar(roi_counts(:,1))

rmInd = isnan(p_roi);
stats(rmInd) = [];
roiList(rmInd) = [];
retain_roi(rmInd) = [];
roi_counts(rmInd) = [];
p_roi(rmInd) = [];
num_contacts(rmInd) = [];
num_subj (rmInd) = [];
disp('FDR p < 0.05');
disp(roiList(p_roi<=alfa_thresh & roi_counts>expAlfa))
disp('uncorrected p < 0.05:::::::');
disp(roiList(p_roi<=0.05 & roi_counts>expAlfa))
if isempty(roiList)
    disp('No SIG REGIONS')
else
    %swagFig([0.1848    0.0982    0.5570    0.2668]);
    %bar([roi_counts;1-roi_counts]','stacked')
    hold all;
    plot(roi_counts,'linewidth',2,'color',kol)
    plot(roi_counts,'x','markersize',15,'color','k')
    set(gca,'xtick',1:length(roiList));
    set(gca,'xticklabel',roiList);
    swagAxes(gca,12,'Region of interest','Fraction of electrodes')
    set(gca,'xlim',[.5 length(roiList)+0.5])
end

function[r,p,x,y] = xSubjCorr(ret,posFlag,groupData,statsStruct)
%this fcn looks at the strength of regression effects vs. accuracy
[groupData,statsStruct] = collapse_w_subj(groupData(ret),statsStruct(ret));
x = [statsStruct.acc10]';%[groupData.acc]';
if posFlag ==1 
    y = [statsStruct.pos_tBeta]';
else
    y = [statsStruct.neg_tBeta]';
end
y = y(~isnan(x));
x = x(~isnan(x));
x = x(~isnan(y));
y = y(~isnan(y));
swagFig;
plot(x,y,'o','markeredgecolor',[.6 .6 .6],'markerfacecolor',[.3 .3 .3],'markersize',8)
b = regress(y,[ones(size(x)) x]);
olsstats = ols(y,[ones(size(x)) x x.^2]);
[~, ~,~] = regression_line_ci(0.05,b,x,y);
[r,p] = corr(x,y);
swagAxes(gca,12,'Accuracy',...
    't-stat',['r ' num2str(round(r*100)/100) '; p ' num2str(round(p*100)/100)],1)

function[r,p] = xSubjCorr_fb(ret,posNegFlag,groupData,statsStruct)
%this fcn looks at the strength of pos v. neg feedback effects vs. accuracy
[groupData,statsStruct] = collapse_w_subj(groupData(ret),statsStruct(ret));
x = [statsStruct.acc10]';%[groupData.acc]';
if posNegFlag ==1 
    y = [groupData.posClusPeak]';
elseif posNegFlag ==2 
    y = [groupData.negClusPeak]';
elseif posNegFlag ==3
    y = nanmean([[groupData.posClusPeak]',[groupData.negClusPeak]'],2);
end
y = y(~isnan(x));
x = x(~isnan(x));
x = x(~isnan(y));
y = y(~isnan(y));
swagFig;
plot(x,y,'o','markeredgecolor',[.6 .6 .6],'markerfacecolor',[.3 .3 .3],'markersize',8)
b = regress(y,[ones(size(x)) x]);
olsstats = ols(y,[ones(size(x)) x x.^2]);
[~, ~,~] = regression_line_ci(0.05,b,x,y);
[r,p] = corr(x,y);
swagAxes(gca,12,'Accuracy',...
    't-stat',['r ' num2str(round(r*100)/100) '; p ' num2str(round(p*100)/100)],1)

function[r,p] = xSubjReg(ret,posFlag,groupData,statsStruct)
[groupData,statsStruct] = collapse_w_subj(groupData(ret),statsStruct(ret));
x = [statsStruct.sumSq]';
x2 = [groupData.acc]';
if posFlag ==1 
    y = [statsStruct.pos_tBeta]';
else
    y = [statsStruct.neg_tBeta]';
end

y = y(~isnan(x));
x2 = x2(~isnan(x));
x = x(~isnan(x));

swagFig;
plot(x,y,'o','markeredgecolor',[.6 .6 .6],'markerfacecolor',[.3 .3 .3],'markersize',8)
b = regress(y,[ones(size(x)) x]);
olsstats = ols(y,[ones(size(x)) x x2]);
[~, ~,~] = regression_line_ci(0.05,b,x,y);

t = olsstats.tstat(3);
p =getP_local(olsstats.tstat(3),olsstats.nobs);
swagAxes(gca,12,'Accuracy',...
    't-stat',['t ' num2str(round(t*100)/100) '; p ' num2str(round(p*100)/100)],1)


function[r,p] = xSubjCorr_posNeg(ret,groupData,statsStruct)
[groupData,statsStruct] = collapse_w_subj(groupData(ret),statsStruct(ret));
x = [groupData.acc]';
y = [statsStruct.meanT]';
y = y(~isnan(x));
x = x(~isnan(x));
x = x(~isnan(y));
y = y(~isnan(y));
swagFig;
plot(x,y,'o','markeredgecolor',[.6 .6 .6],'markerfacecolor',[.3 .3 .3],'markersize',8)
b = regress(y,[ones(size(x)) x]);
olsstats = ols(y,[ones(size(x)) x x.^2]);
[~, ~,~] = regression_line_ci(0.05,b,x,y);
[r,p] = corr(x,y);
swagAxes(gca,12,'Accuracy',...
    't-stat',['r ' num2str(round(r*100)/100) '; p ' num2str(round(p*100)/100)],1)



function [vecs,lbls] = avgT_wrapper(xSubjFlag,groupData,statsStruct,ret,lbl_pos,lbl_neg,powConfig,yL,yL2)
if ~exist('yL','var')||isempty(yL)
    yL = [];
end
if ~exist('yL2','var')||isempty(yL2)
    yL2 = [];
end
plotPowVec_local(statsStruct(ret),yL2,lbl_pos,lbl_neg,powConfig);
if xSubjFlag == 1
    [groupData,statsStruct] = collapse_w_subj(groupData(ret),statsStruct(ret));
else 
    statsStruct = statsStruct(ret);
end
plotPowVec_local(statsStruct,yL2,lbl_pos,lbl_neg,powConfig);
%[pVec,tstats] = plotAvgT_local(statsStruct,yL);
plotPowBar_local(statsStruct,yL2,lbl_pos,lbl_neg);

% pos 
vecs = [];lbls = {};
for i = 1:length(lbl_pos)
    vecs(:,end+1) = [statsStruct.(lbl_pos{i})];
    lbls(end+1) = lbl_pos(i);
end
% neg 
for i = 1:length(lbl_neg)
    vecs(:,end+1) = [statsStruct.(lbl_neg{i})];
    lbls(end+1) = lbl_neg(i);
end


function[catLbls,catList_pos,catList_neg] = ...
    doCounts_local(statsStruct,config,retStruct,plotFlag)
% How many sig. contacts?
retain_sig_pos = [statsStruct.pos_p]<=config.alfa;
retain_sig_neg = [statsStruct.neg_p]<=config.alfa;
retain_sig =retain_sig_pos|retain_sig_neg;
[chi2stat,p,df] = chi2test([[sum(retain_sig) sum(~retain_sig)]',...
    [(config.alfa*2)*length(retain_sig) (1-(config.alfa*2))*length(retain_sig)]']);

retain_sig_pos_posT = retain_sig_pos&[statsStruct.pos_tBeta]>0;
retain_sig_pos_negT = retain_sig_pos&[statsStruct.pos_tBeta]<0;
retain_sig_neg_posT = retain_sig_neg&[statsStruct.neg_tBeta]>0;
retain_sig_neg_negT = retain_sig_neg&[statsStruct.neg_tBeta]<0;


% make category labels
catLbls.pos.negT = retain_sig_pos_negT;
catLbls.pos.posT = retain_sig_pos_posT;
catLbls.pos.nsig = ~retain_sig_pos;
catList_pos = fieldnames(catLbls.pos);

catLbls.neg.negT = retain_sig_neg_negT;
catLbls.neg.posT = retain_sig_neg_posT;
catLbls.neg.non_sig = ~retain_sig_neg;
catList_neg = fieldnames(catLbls.neg);

if plotFlag == 1
    % all contacts
    lbl ='pos';catList =catList_pos;
    for c = 1:length(catList);
        sumVec(1,c) = sum(catLbls.(lbl).(catList{c}));
    end
    sumVec(1,sumVec==0) = eps;
    
    lbl ='neg';catList =catList_neg;
    for c = 1:length(catList);
        sumVec(2,c) = sum(catLbls.(lbl).(catList{c}));
    end
    sumVec(2,sumVec==0) = eps;
    swagFig; hold all
    frac_counts = sumVec(:,1:2)./sum(sumVec(1,:),2);
    bar(frac_counts,'grouped')
    plot(get(gca,'xlim'),[config.alfa/2 config.alfa/2],'--k')
    %plot(frac_counts(1,:),'-','markersize',15,'color',[.6 .6 .6])
    %plot(frac_counts(1,:),'xk','markersize',15)
    %plot(frac_counts(2,:),'-','markersize',15,'color',[.6 .6 .6])
    %plot(frac_counts(2,:),'xk','markersize',15)
    legend(regexprep(catList,'_','-'),'location','northeastoutside')
    title('Valence-encoding Contacts')
    set(gca,'xlim',[.5 2.5])
    clear sumVec
    
    % pos contacts
    swagFig([ 0.5000    0.6280    0.4766    0.3232]); 
    subplot(1,2,1); lbl ='pos';catList =catList_pos;
    for c = 1:length(catList);
        sumVec(c) = sum(catLbls.(lbl).(catList{c}) & retStruct.retain_pos);
    end
    sumVec(sumVec==0) = eps;
    explode = zeros(1,length(catList));explode(end) = 1;
    pie(sumVec,explode);clear sumVec
    legend(regexprep(catList,'_','-'),'location','northeastoutside')
    title('Positive-encoding Contacts')

    subplot(1,2,2); lbl ='neg';catList =catList_neg;
    for c = 1:length(catList);
        sumVec(c) = sum(catLbls.(lbl).(catList{c}) & retStruct.retain_pos);
    end
    sumVec(sumVec==0) = eps;
    explode = zeros(1,length(catList));explode(end) = 1;
    pie(sumVec,explode);clear sumVec
    legend(regexprep(catList,'_','-'),'location','northeastoutside')
    title('Positive-encoding Contacts')

    % neg contacts
    swagFig([ 0.5000    0.6280    0.4766    0.3232]); 
    subplot(1,2,1); lbl ='pos';catList =catList_pos;
    for c = 1:length(catList);
        sumVec(c) = sum(catLbls.(lbl).(catList{c}) & retStruct.retain_neg);
    end
    sumVec(sumVec==0) = eps;
    explode = zeros(1,length(catList));explode(end) = 1;
    pie(sumVec,explode);clear sumVec
    legend(regexprep(catList,'_','-'),'location','northeastoutside')
    title('Negative-encoding Contacts')

    subplot(1,2,2); lbl ='neg';catList =catList_neg;
    for c = 1:length(catList);
        sumVec(c) = sum(catLbls.(lbl).(catList{c}) & retStruct.retain_neg);
    end
    sumVec(sumVec==0) = eps;
    explode = zeros(1,length(catList));explode(end) = 1;
    pie(sumVec,explode);clear sumVec
    legend(regexprep(catList,'_','-'),'location','northeastoutside')
    title('Negative-encoding Contacts')
end


function[pVec,tstats] = plotAvgT_local(statsStruct,yL)
swagFig([ 0.7504    0.5551    0.1359    0.3961]);hold all
bar([1 2],mean([[statsStruct.pos_tBeta]' [statsStruct.neg_tBeta]']),'facecolor',[.6 .6 .6]);
errorbar([1 2],mean([[statsStruct.pos_tBeta]' [statsStruct.neg_tBeta]']),...
SEM([[statsStruct.pos_tBeta]' [statsStruct.neg_tBeta]']),'.k','linewidth',3)
swagAxes(gca,12,'Feedback type','t-statistic (beta)','',1);
set(gca,'xlim',[.5 2.5],'xtick',[1 2],'xticklabel',{'pos','neg'})
[~,pVec(1),~,tstats(1)] = ttest([statsStruct.pos_tBeta]');
[~,pVec(2),~,tstats(2)] = ttest([statsStruct.neg_tBeta]');
[~,pVec(3),~,tstats(3)] = ttest2([statsStruct.pos_tBeta]',[statsStruct.neg_tBeta]');

if exist('yL','var') &~isempty(yL)
   set(gca,'ylim',yL) 
end


function[] = plotPowBar_local(statsStruct,yL,lbl_pos,lbl_neg)
swagFig([0.6121    0.7091    0.3527    0.2421])
subplot(1,2,1);hold all
for i = 1:length(lbl_pos)
    bar(i,nanmean([statsStruct.(lbl_pos{i})]),'facecolor',[.6 .6 .6]);
    errorbar(i,nanmean([statsStruct.(lbl_pos{i})]),SEM([statsStruct.(lbl_pos{i})]')...
        ,'.k','linewidth',3);
end
swagAxes(gca,12,'Positive Feedback Type','z Power',['n = ' num2str(length(statsStruct))],1);
set(gca,'xlim',[.5 3.5],'xtick',[1 2 3],'xticklabel',lbl_pos)
yl = get(gca,'ylim');

subplot(1,2,2);hold all
for i = 1:length(lbl_neg)
    bar(i,nanmean([statsStruct.(lbl_neg{i})]),'facecolor',[.6 .6 .6]);
    errorbar(i,nanmean([statsStruct.(lbl_neg{i})]),SEM([statsStruct.(lbl_neg{i})]')...
        ,'.k','linewidth',3);
end
swagAxes(gca,12,'Positive Feedback Type','z Power','',1);
set(gca,'xlim',[.5 3.5],'xtick',[1 2 3],'xticklabel',lbl_neg)
yl =[yl get(gca,'ylim')];

if exist('yL','var') &&~isempty(yL)
   subplot(1,2,1)
   set(gca,'ylim',yL) 
   subplot(1,2,2)
   set(gca,'ylim',yL) 
else
   subplot(1,2,1)
   set(gca,'ylim',[min(yl) max(yl)]) 
   subplot(1,2,2)
   set(gca,'ylim',[min(yl) max(yl)]) 
end
function[] = plotPowVec_local(statsStruct,yL,lbl_pos,lbl_neg,powConfig)
kol_pos = [.8 1 .8;.4 1 .4;0 1 0];
kol_neg = [1 .8 .8;1 .4 .4;1 0 0];
[~,zeroInd] = min(abs(powConfig.timeWins_lbl));

swagFig([0.6121    0.7091    0.3527    0.2421])
subplot(1,2,1);hold all
for i = 1:length(lbl_pos)
    plot_local(statsStruct,[lbl_pos{i} '_vec'],kol_pos(i,:))
end
swagAxes(gca,12,'Time from feedback (ms)','z Power',['n = ' num2str(length(statsStruct))]);
xt = get(gca,'xtick');xt(1) = 1;
set(gca,'xticklabel',powConfig.timeWins_lbl(xt));
yl = get(gca,'ylim');
subplot(1,2,2);hold all
for i = 1:length(lbl_neg)
    plot_local(statsStruct,[lbl_neg{i} '_vec'],kol_neg(i,:))
end
swagAxes(gca,12,'Time from feedback (ms)','z Power','');
xt = get(gca,'xtick');xt(1) = 1;
set(gca,'xticklabel',powConfig.timeWins_lbl(xt));
yl =[yl get(gca,'ylim')];
drawVertLine(gca,zeroInd);
if exist('yL','var') &&~isempty(yL)
   subplot(1,2,1)
   set(gca,'ylim',yL); drawVertLine(gca,zeroInd);
   subplot(1,2,2)
   set(gca,'ylim',yL); drawVertLine(gca,zeroInd);
else
   subplot(1,2,1)
   set(gca,'ylim',[min(yl) max(yl)]); drawVertLine(gca,zeroInd); 
   subplot(1,2,2)
   set(gca,'ylim',[min(yl) max(yl)]); drawVertLine(gca,zeroInd); 
end

function[] = plot_local(compPowStruct,lbl,kol)
powVec = cat(1,compPowStruct.(lbl));
plotSEM(1:size(powVec,2),...
    nanmean(powVec,1),SEM(powVec),kol);
plot(1:size(powVec,2),...
    nanmean(powVec,1),'k','linewidth',3);
    
function[retStruct] = getRetStruct_local(groupData,config)
[~,retain_pos,...
    retain_neg,retain_posNeg,...
    retain_nsig] = idSig_local(groupData,config);

% make retain phasic and tonic 
    onset_vec = nan(1,length(groupData));
    onset_vec(retain_pos) = [groupData(retain_pos).posClusOnset];
    onset_vec(retain_neg) = [groupData(retain_neg).negClusOnset];

    offset_vec = nan(1,length(groupData));
    offset_vec(retain_pos) = [groupData(retain_pos).posClusOffset];
    offset_vec(retain_neg) = [groupData(retain_neg).negClusOffset];

    phasic_idx =onset_vec>config.onset_thresh(1)& ...
        onset_vec<config.onset_thresh(2) &...
        (offset_vec-onset_vec)<config.duration_thresh;
    tonic_idx = onset_vec>config.onset_thresh(1)& ...
        onset_vec<config.onset_thresh(2) &...
        (offset_vec-onset_vec)>=config.duration_thresh;

    %roiList = unique({groupData.anatRegion});
    roiList = unique([groupData.ROI]);
    xyz = cat(1,groupData.xyz);
    for i = 1:length(roiList)
        ret = strcmp([groupData.ROI],roiList{i});
        retain_roi{i} = ret; 
        numSubj(i) = length(unique({groupData(ret).subj}));
        if ~isempty(regexp(roiList{i},'OTHER','once'))
            numSubj(i) = 0;
        end
    end
    
    %remove regions with less than 5 subj
    rmInd = numSubj<1;
    roiList(rmInd) = [];
    retain_roi(rmInd) = [];
    %sort by label
    for i = 1:length(roiList)
        thisLbl = regexp(roiList{i},'_','split');
        uROI_list{i} = thisLbl{2};
    end
    [~,sortIdx] = sort(uROI_list);
    roiList = roiList(sortIdx);
    retain_roi = retain_roi(sortIdx);
    %update retStruct
    retStruct.retain_pos = retain_pos;
    retStruct.retain_neg = retain_neg;
    retStruct.retain_posNeg = retain_posNeg;
    retStruct.retain_nsig = retain_nsig;
    retStruct.retain_phasic = phasic_idx;
    retStruct.retain_tonic = tonic_idx;
    retStruct.retain_roi = retain_roi;
    retStruct.roiList = roiList;
    
    %sort by label
    for i = 1:length(roiList)
        thisLbl = regexp(roiList{i},'_','split');
        uROI_list{i} = thisLbl{2};
    end
    [~,sortIdx] = sort(uROI_list);
    roiList = roiList(sortIdx);
    retain_roi = retain_roi(sortIdx);
    
function[numElecs,retain_pos,retain_neg,retain_posNeg,retain_nsig] = idSig_local(groupData,config)
    alfa = config.alfa;
    numElecs = length(groupData);
    retain_pos = ([groupData.posClusP]<alfa)&isnan([groupData.negClusP]);
    retain_neg = ([groupData.negClusP]<alfa)&isnan([groupData.posClusP]);
    retain_posNeg = ([groupData.posClusP]<alfa)&([groupData.negClusP]<alfa);
    retain_nsig = ~retain_pos&~retain_neg&~retain_posNeg;


function [statsStruct,lbl_pos,lbl_neg] = pairWise_local(groupData,retLbl,compar,powConfig,config,lbl_pos,lbl_neg)
% identifies the index of time 0 in the pow config
[~,zeroInd] = min(abs(powConfig.timeWins_lbl));
compar_dir =  fullfile(config.clusStatsInfo_rootDir,compar,...
    ['powConfig' num2str(config.powConfigNum) '-' num2str(config.fRange(1)) '-' num2str(config.fRange(2))]);


cd(config.saveDir)
saveFile = [retLbl '-' compar '.mat'];

if exist(saveFile,'file')
    load(saveFile)
else
    statsStruct = struct;
    iStart = 1;
end

% loops through each electrode
for i = iStart:length(groupData)
    % label of this electrode (for loading purposes, see below)
    fname = [groupData(i).subj '-' groupData(i).eName];
    
    % identifies the apropriate folder for cluster info (implement prestim etc. here)
    % get pos-neg clusStats
    cd(config.clusStatsInfo_dir)
    
    % load file name
    load(fname)
    
    % identify the comparison of interest
    clusStats = compPowStruct.posVneg;
    
    % identifies the time interval associated with the lagest significant cluster
    % first chooses the largest positive and negative cluster
    pos_ind = []; neg_ind = [];
    if ~isempty(clusStats.posClusStatsP)
        pos_ind = clusStats.posClusInd{1};
    end
    if ~isempty(clusStats.negClusStatsP)
        neg_ind = clusStats.negClusInd{1};
    end
    
    % then selects the larger of the two (alternative: choose which one to use 
    % based on the larger clus stat).
    if length(pos_ind)>length(neg_ind)
        t_ind = pos_ind;
    else
        t_ind = neg_ind;
    end
    
    % onset, offset, and mean t-statistic associated with this 
    % interval of interest
    statsStruct(i).onset = t_ind(1);
    statsStruct(i).offset = t_ind(end);
    statsStruct(i).meanT = nanmean(clusStats.tVec(ismember(powConfig.timeWins_lbl,t_ind)));
    
    % go to compar directory
    cd(compar_dir)
    load(fname)
    
    % run regression on power values collapsed within the chosen time interval of
    % interest
    
    % only positive feedback trials first
    %set up a regression variables
    regVar = [];regLbl = [];
    for j = 1:length(lbl_pos)
        [rate,rate_vec] = getRate_local(compPowStruct,lbl_pos{j},t_ind,powConfig);
        statsStruct(i).(lbl_pos{j}) = mean(rate);
        statsStruct(i).([lbl_pos{j} '_vec']) = mean(rate_vec,1); 
        % this is for the pairwise regression (differences between item
        % pair)
        regVar = [regVar;rate];regLbl = [regLbl;j*ones(size(rate))];
    end
    % run regression: 
    switch compar
        %power = b0 + b1(expectation)  + b2(number of times
        % this pair has been presented)
        case {'fb_RPE_LRN','fb_RPE_train'} 
            ev = [compPowStruct.fbEvents];
            % trial num x exp_choice
            [rate] = getRate_local(compPowStruct,...
                'fb_pos',t_ind,powConfig);
            if ~isempty(ev)
                olsStats = ols(rate,[ones(size(rate)),...
                    [compPowStruct.modelStats.exp_choice([ev.fb]==1)]' [ev([ev.fb]==1).tnum]']);
               
                % collect information about the model fit for this subject
                statsStruct(i).sumSq = compPowStruct.modelStats.sumSq;
                statsStruct(i).alpha = compPowStruct.paramStruct.alpha_w;
                statsStruct(i).beta = compPowStruct.paramStruct.beta; 
                statsStruct(i).acc10 = compPowStruct.behStats.acc10;
                statsStruct(i).winStay = compPowStruct.behStats.winStay;
                statsStruct(i).loseSwitch = compPowStruct.behStats.loseSwitch;
            else
                statsStruct(i).sumSq = nan;
                statsStruct(i).alpha = nan;
                statsStruct(i).beta = nan;
                statsStruct(i).acc10 = nan;
                statsStruct(i).winStay = nan;
                statsStruct(i).loseSwitch = nan;
            end
        % early vs. late regression
        %power = b0 + b1 (number of times
        % this pair has been presented)
        case 'fb_earlyLate' 
            ev = [compPowStruct.fbEvents];
            % trial num x exp_choice
            [rate] = getRate_local(compPowStruct,...
                'fb_pos',t_ind,powConfig);
            if ~isempty(ev)
                olsStats = ols(rate,[ones(size(rate)),[ev([ev.fb]==1).tnum]']);
               
                % collect information about the model fit for this subject
                statsStruct(i).sumSq = nan;
                statsStruct(i).alpha = nan;
                statsStruct(i).beta = nan; 
                statsStruct(i).acc10 = nan;
                statsStruct(i).winStay = nan;
                statsStruct(i).loseSwitch = nan;
            else
                statsStruct(i).sumSq = nan;
                statsStruct(i).alpha = nan;
                statsStruct(i).beta = nan;
                statsStruct(i).acc10 = nan;
                statsStruct(i).winStay = nan;
                statsStruct(i).loseSwitch = nan;
            end
        otherwise
            % This is for regressing the pair number
            olsStats = ols(regVar,[ones(size(regVar)), regLbl]);
    end
                
    %collect stats %(this is outside the switch statement above; always
    %grabs the 2nd beta)
    if ~isempty(ev) 
        statsStruct(i).pos_tBeta = olsStats.tstat(2); 
        statsStruct(i).pos_df = olsStats.nobs-1;
        statsStruct(i).pos_p =getP_local(olsStats.tstat(2),olsStats.nobs);
    else
        statsStruct(i).pos_tBeta = nan;
        statsStruct(i).pos_df = nan;
        statsStruct(i).pos_p = nan;
    end
        
    % repeat above process for negative feedback trials
    regVar = [];regLbl = [];
    for j = 1:length(lbl_neg)
        [rate,rate_vec] = getRate_local(compPowStruct,lbl_neg{j},t_ind,powConfig);
        regVar = [regVar;rate];regLbl = [regLbl;j*ones(size(rate))];
        statsStruct(i).(lbl_neg{j}) = mean(rate);
        statsStruct(i).([lbl_neg{j} '_vec']) = mean(rate_vec,1);
    end
    switch compar
        case {'fb_RPE_LRN','fb_RPE_train'}
            ev = [compPowStruct.fbEvents];
            % trial num x exp_choice
            [rate] = getRate_local(compPowStruct,...
                'fb_neg',t_ind,powConfig);
            if ~isempty(ev)
                olsStats = ols(rate,[ones(size(rate)),...
                    [compPowStruct.modelStats.exp_choice([ev.fb]==0)]' [ev([ev.fb]==0).tnum]']);
            end
        % early vs. late regression
        %power = b0 + b1 (number of times
        % this pair has been presented)
        case 'fb_earlyLate' 
            ev = [compPowStruct.fbEvents];
            % trial num x exp_choice
            [rate] = getRate_local(compPowStruct,...
                'fb_neg',t_ind,powConfig);
            if ~isempty(ev)
                olsStats = ols(rate,[ones(size(rate)),[ev([ev.fb]==0).tnum]']);
            end
        otherwise
            olsStats = ols(regVar,[ones(size(regVar)), regLbl]);
    end    
    %collect stats 
    if ~isempty(ev) 
        statsStruct(i).neg_tBeta = olsStats.tstat(2);
        statsStruct(i).neg_df = olsStats.nobs-1;
        statsStruct(i).neg_p =getP_local(olsStats.tstat(2),olsStats.nobs);
    else
        statsStruct(i).neg_tBeta = nan;
        statsStruct(i).neg_df = nan;
        statsStruct(i).neg_p = nan;
    end
    %iteratively save
    cd(config.saveDir);
    iStart = i+1;
    save(saveFile,'statsStruct','iStart')
    disp(i)
end
function [groupData_subj,statsStruct_subj] = collapse_w_subj(groupData,statsStruct);
subj_list = unique({groupData.subj});
names = fieldnames(groupData);
groupData_subj = struct;statsStruct_subj = struct;
for s = 1:length(subj_list)
    retain_subj = strcmp(subj_list{s},{groupData.subj});
    names = fieldnames(groupData);
    for n = 1:length(names)
        switch names{n}
            case {'subj','eName','acc','anatRegion','anatRegion_indiv','ROI','eType'} %grab first entry
                groupData_subj(s).(names{n}) = ...
                    groupData(find(retain_subj,1)).(names{n}); 
            case {'posClusP','negClusP','pos_p','pos_df','neg_p','neg_df'} % take min
                groupData_subj(s).(names{n}) = ...
                    min(cat(1,groupData(retain_subj).(names{n})));
            otherwise % get mean value
                groupData_subj(s).(names{n}) = ...
                    nanmean(cat(1,groupData(retain_subj).(names{n})),1);
        end
    end
    names = fieldnames(statsStruct);
    for n = 1:length(names)
        switch names{n}
            case {'subj','eName','acc','anatRegion','ROI','eType'} %grab first entry
                statsStruct_subj(s).(names{n}) = ...
                    statsStruct(find(retain_subj,1)).(names{n}); 
            case {'posClusP','negClusP','pos_p','pos_df','neg_p','neg_df'} % take min
                statsStruct_subj(s).(names{n}) = ...
                    min(cat(1,statsStruct(retain_subj).(names{n})));
            otherwise % get mean value
                statsStruct_subj(s).(names{n}) = ...
                    nanmean(cat(1,statsStruct(retain_subj).(names{n})),1);
        end
    end
end
function[rate,rate_vec] = getRate_local(compPowStruct,lbl,t_ind,powConfig)
rate_vec = compPowStruct.(lbl);
rate = nanmean(rate_vec(:,ismember(powConfig.timeWins_lbl,t_ind)),2);

function [p] = getP_local(tstat,nobs)
p=tcdf(tstat,nobs-1);
p=min(p, 1-p);

function [] = make_timing_heatmap(statStruct,config,powConfig,cL,mtype)

onset = [statStruct.onset];
offset = [statStruct.offset];

% timing heat map
timeBinSize = 100;
timeBinStep = 10;
timeBinDur = powConfig.postMS+powConfig.priorMS;
t_ends=[timeBinSize:timeBinStep:timeBinDur]-powConfig.priorMS;
t_starts = t_ends-timeBinSize+1;
timeBins = [t_starts' t_ends'];
t_lbl = mean(timeBins,2);
timing_heatmap = nan(size(timeBins,1),size(timeBins,1));
for t_on = 1:size(timeBins,1)
    for t_offset = 1:size(timeBins,1)

        onset_match = (onset<timeBins(t_on,2) & onset>=timeBins(t_on,1));
        offset_match = (offset<timeBins(t_offset,2) & offset>=timeBins(t_offset,1));

        numContacts = sum(onset_match&offset_match);
        timing_heatmap(t_offset,t_on) = numContacts;

    end
end
timing_heatmap(timing_heatmap==0) = nan;
swagFig([ 0.4375    0.4087    0.4375    0.2611]);
subplot(1,2,1)
plot([onset],[offset],mtype)%,'marker'
drawVertLine(gca,0)

subplot(1,2,2)
imagescnan(timing_heatmap);
set(gca,'ydir','normal','clim',cL); colorbar
[~,zero_ind] = min(abs(t_lbl));  [~,end_ind] = min(abs(t_lbl-powConfig.postMS)); 
xl = get(gca,'xlim');
hold all;
plot([xl(1):xl(2)],[xl(1):xl(2)],'linestyle','-','linewidth',3,'color','k')
swagAxes(gca,12,'Onset (ms)','Offset (ms)')
set(gca,'xlim',[zero_ind end_ind],'ylim',[zero_ind end_ind])
xt = get(gca,'xtick');yt = get(gca,'ytick');
set(gca,'xticklabel',t_lbl(xt),'yticklabel',t_lbl(yt))
drawVertLine(gca,zero_ind)
    
