function [] = ps2_ecog_subjPow_beh_learn(filtLbl,modelLbl)
% computes behavioral analyses on training data

% get config
behConfig = config_local;

% behav. analyses
[behStats] = collectBeh_local(filtLbl);


% plot acc first 10 and last 10 (all pairs)
swagFig;
acc01 =plotBar_local(behStats,'acc01',1);
acc10 =plotBar_local(behStats,'acc10',2);
swagAxes(gca,16,'','Accuracy')
set(gca,'ylim',[0.5 .75],'xlim',[.5 2.5])
[~,p,~,stats] = ttest(acc10,0.5);
[~,p,~,stats] = ttest(acc10,acc01,0.5);


% plot win-stay, lose-switch first 10 trials
swagFig;
wstay =plotBar_local(behStats,'winStay',1);
lswitch =plotBar_local(behStats,'loseSwitch',2);
swagAxes(gca,16,'','Probability')
set(gca,'xtick',[1 2],'xticklabel',{'win-stay', 'lose-switch'})
set(gca,'ylim',[0.5 .9],'xlim',[.5 2.5])

[~,p,~,stats] = ttest(wstay,0.5);
[~,p,~,stats] = ttest(lswitch,0.5);
[~,p,~,stats] = ttest(wstay,lswitch);


% acc10 vs. win-stay and lose-switch
swagFig;
acc = [behStats.acc]';
plot(acc,wstay,'o')
swagFig;
plot(acc,lswitch,'o')
stats = ols(acc,[ones(size(wstay)) wstay lswitch]);

% Model-stuff
if ~isempty(modelLbl)
  [modelStats,paramStruct] = collectModel_local(filtLbl,modelLbl);
end

% plot LCs
subjList = unique({behStats.uSubj});
for s = 1:length(subjList)
   
   % model fit p-value
   [pVal(s),~,sumSq_thresh(s)] = ...
       sumSq_null_local(modelStats(s).sumSq,behStats(s).numTrials,behConfig.iters,behConfig.alfa);
   
   %plot LC
   plotLc_local(subjList{s},behStats,modelStats,paramStruct) 
end
keyboard

%%%% FUNCTIONS %%%%%
function [vec] = plotBar_local(behStats,lbl,xVal)
vec = cat(1,behStats.(lbl));

bar(xVal,nanmean(vec),'facecolor',[.6 .6 .6]);
hold all
errorbar(xVal,nanmean(vec),SEM(vec),'.k','linewidth',3);

function [] = plotLc_local(uSubj,behStats,modelStats,paramStruct)
ret = strcmp({behStats.uSubj},uSubj);
behStats = behStats(ret);
modelStats = modelStats(ret);
paramStruct = paramStruct(ret);
swagFig([0.1680    0.7795    0.8098    0.1717]);hold all
correct = [behStats.correct];fb = [behStats.fb];
ret = [behStats.pairNum] == 0;%smoothBinaryVec(correct(ret),2,1)
plot(find(ret),correct(ret),'.b','linewidth',2,'markersize',15);set(gca,'ylim',[-.2 1.2])
ret = [behStats.pairNum] == 1;%smoothBinaryVec(correct(ret),2,1)
plot(find(ret),correct(ret),'.g','linewidth',2,'markersize',15);set(gca,'ylim',[-.2 1.2])
ret = [behStats.pairNum] == 2;%smoothBinaryVec(correct(ret),2,1)
plot(find(ret),correct(ret),'.r','linewidth',2,'markersize',15);set(gca,'ylim',[-.2 1.2])
plot(modelStats.p_a,'-','linewidth',2,'color',[.6 .6 .6]);set(gca,'ylim',[-.2 1.2])
plot(find(fb==1),(1.1)*ones(1,sum(fb==1)),'*k')
plot(find(fb==0),(-.1)*ones(1,sum(fb==0)),'*k')
title([uSubj '-alpha ' num2str(paramStruct.alpha_w) '...beta' num2str(paramStruct.beta) '...sumSq ' num2str(modelStats.sumSq)]);

function [pVal,sumSq_null_vec,sumSq_thresh] = sumSq_null_local(sumSq,numTrials,iters,fpRate)

%null sum sq
p_choice = random('bino',1,0.5*ones(iters,numTrials));
sumSq_null_vec =  nansum((1-p_choice).^2,2)/size(p_choice,2);
sumSq_thresh = prctile(sumSq_null_vec,fpRate);    
pVal = sum(sumSq_null_vec<=sumSq)/iters;



function [behConfig] = config_local();
dirs = ps2_dirs;
behConfig.saveDir = fullfile(dirs.analyses,'ecog','subjPow','beh','learn');
behConfig.iters = 10000;
behConfig.alfa = 0.05;

function [modelStats,paramStruct] = collectModel_local(filtLbl,modelLbl)
[behConfig] = config_local();
subjSessList = ps2_ecog_subjPow_getSubjList;

cd_mkdir(behConfig.saveDir);
fname = ['modelStats_' filtLbl '-' modelLbl '.mat'];
if exist(fname,'file')
    load(fname)
else
    modelStats = struct;
    sStart = 1;
    count = 0;
end
for s = sStart:length(subjSessList)
    uSubj = subjSessList(s).subj;
    
    [~,~,pair_list,fb_pair_lbl,~,fbEvents] = ...
        ps2_ecog_subjPow_filtSubjEv(uSubj,filtLbl);
    
    if ~isempty(fbEvents)
        count = count+1;

        % get model stats
        if count == 1
            [modelStats,paramStruct] = ps2_ecog_subjPow_rlModel(uSubj,filtLbl,modelLbl);
        else
            [modelStats(count),paramStruct(count)] = ps2_ecog_subjPow_rlModel(uSubj,filtLbl,modelLbl);
        end
    end
    cd(behConfig.saveDir)
    sStart = s+1;
    save(fname,'modelStats','paramStruct','sStart','count')  
    disp(s)
end



function [behStats] = collectBeh_local(filtLbl);

[behConfig] = config_local();
subjSessList = ps2_ecog_subjPow_getSubjList;

cd_mkdir(behConfig.saveDir);
fname = ['behStats_' filtLbl '.mat'];
if exist(fname,'file')
    load(fname)
else
    behStats = struct;
    sStart = 1;
    count = 0;
end

for s = sStart:length(subjSessList)
    uSubj = subjSessList(s).subj;
    
    [~,~,pair_list,fb_pair_lbl,~,fbEvents] = ...
        ps2_ecog_subjPow_filtSubjEv(uSubj,filtLbl);
    
    if ~isempty(fbEvents)
        count = count+1;

        % get beh stats
        if count == 1
            [behStats] = behStats_local(uSubj,fbEvents,fb_pair_lbl,pair_list);
        else
            [behStats(count)] = behStats_local(uSubj,fbEvents,fb_pair_lbl,pair_list);
        end 
    end
    cd(behConfig.saveDir)
    sStart = s+1;
    save(fname,'behStats','sStart','count')  
    disp(s)
end

function[behStats] = behStats_local(uSubj,events,fb_pair_lbl,pair_list)
correct = [events.correct];
button = [events.button];
for p = 1:length(pair_list)
    pairIdx = strcmp(pair_list{p},fb_pair_lbl);
    
    % early idx
    early_idx = false(size(pairIdx));
    early_idx(find(pairIdx,10,'first')) = true;
  
    fb = [events.fb]==1; %reward trials
    fb_lag1 = circshift(fb,[0 1]); %trials after wins (1) or losses (0)
    samePair_lag1 = [0 (diff(pairIdx))==0]; %trials where pair was same as prev trial
    sameItem_lag1 = [0 (diff(correct))==0]; %trials where the item choice was same as prev trial
    sameButton_lag1 = [0 (diff(button))==0]; %trials where the button choice was same as prev trial

    % pair number 
    thisStats(p).pairNum = unique([events(pairIdx).pairNum]);
    
    %num trials
    thisStats(p).numTrials = sum(pairIdx);
    
    %pair-wise acc
    thisStats(p).acc = mean(correct(pairIdx));
     
    % acc_01 (accuracy on first 10 trials)
    thisStats(p).acc01 = mean(correct(find(pairIdx,10,'first'))); 
    
    % acc_10 (accuracy on last 10 trials)
    thisStats(p).acc10 = mean(correct(find(pairIdx,10,'last'))); 

    % win-lag1: behavior on (AB) trials following reward where the same pair
    % was available. Only during the first 10 trials
    retain = pairIdx&fb_lag1&samePair_lag1&early_idx;
    thisStats(p).winStay = mean(sameItem_lag1(retain)); %win-same item
    thisStats(p).winSameButton = mean(sameButton_lag1(retain)); %win-same button
    thisStats(p).winStayZ = mean(sameItem_lag1(retain)) - mean(sameItem_lag1(pairIdx&~fb_lag1&samePair_lag1)); %win-same item - lose same item
    
    % lose-lag1: behavior on (AB) trials following loss trials where the same pair 
    % was available. Only during the first 10 trials
    retain = pairIdx&~fb_lag1&samePair_lag1&early_idx;
    thisStats(p).loseSwitch = mean(~sameItem_lag1(retain)); %lose-switch
    thisStats(p).loseSwitchButton = mean(~sameButton_lag1(retain)); %win-switch button
end
behStats = struct;
behStats.uSubj = uSubj;
names = fieldnames(thisStats); 
for n = 1:length(names)
   behStats.(names{n}) = nanmean([thisStats.(names{n})]); 
end

% for plotting
behStats.correct = [events.correct];
behStats.pairNum = [events.pairNum];
behStats.fb = [events.fb];
% by pair
pairNum = [thisStats.pairNum];
pairLbl = {'AB','CD','EF'};
for p = 1:length(pairLbl)
    behStats.(['acc10_' pairLbl{p}]) = nanmean([thisStats(pairNum==p-1).acc10]);
    behStats.(['acc_' pairLbl{p}]) = nanmean([thisStats(pairNum==p-1).acc]);
    behStats.(['winStay_' pairLbl{p}]) = nanmean([thisStats(pairNum==p-1).winStay]);
    behStats.(['winSameButton_' pairLbl{p}]) = nanmean([thisStats(pairNum==p-1).winSameButton]);
    behStats.(['loseSwitch_' pairLbl{p}]) = nanmean([thisStats(pairNum==p-1).loseSwitch]);
    behStats.(['loseSwitchButton_' pairLbl{p}]) = nanmean([thisStats(pairNum==p-1).loseSwitchButton]);
end
