function [filt_fb,filt_ch,pair_list,fb_pair_lbl,ch_pair_lbl,fbEvents,chEvents,fb_pair_lbl_unfilt,ch_pair_lbl_unfilt] = ps2_ecog_subjPow_filtSubjEv(uSubj,filtLbl);
% This function applies various masks on each subjects' events. see filt lbl below
% filt_fb is used for fbEvents, filt_ch can be used for choice and stim
% events. pair_list is list of unique subj-sess-pair lbls

[fbEvents,chEvents] = ps2_ecog_subjPow_getSubjEv(uSubj);

switch filtLbl
    case 'train' % return train trials
        [filt_fb,filt_ch,pair_list,fb_pair_lbl,ch_pair_lbl,fb_pair_lbl_unfilt,ch_pair_lbl_unfilt] =...
            filtLearnPairs_local(fbEvents,chEvents,0,0);    
    case 'LRN'  % return learning pairs
        [filt_fb,filt_ch,pair_list,fb_pair_lbl,ch_pair_lbl,fb_pair_lbl_unfilt,ch_pair_lbl_unfilt] =...
            filtLearnPairs_local(fbEvents,chEvents,0.5,0.7);
    case 'NLRN'  % return non-learning pairs
        [filt_fb,filt_ch,pair_list,fb_pair_lbl,ch_pair_lbl,fb_pair_lbl_unfilt,ch_pair_lbl_unfilt] =...
                filtNonLearnPairs_local(fbEvents,chEvents,0.5,0.6);
    case 'test' % return test trials
        filt_fb = strcmp({fbEvents.type},'test');
        filt_ch = strcmp({chEvents.type},'test');    
end

fbEvents = fbEvents(filt_fb);
chEvents = chEvents(filt_ch);
function[filt_fb,filt_ch,pair_list,fb_pair_lbl,ch_pair_lbl,fb_pair_lbl_unfilt,ch_pair_lbl_unfilt] = filtLearnPairs_local(fbEvents,chEvents,accThresh,acc10Thresh)
% train only
filt_fb = false(size(fbEvents));
filt_ch = strcmp({chEvents.type},'train');        

% unique subj-sess-pair list for fb and ch
for i = 1:length(fbEvents)
   fb_pair_lbl{i} = [fbEvents(i).subject '-' fbEvents(i).session '-' num2str(fbEvents(i).pairNum)];
end
for i = 1:length(chEvents)
   ch_pair_lbl{i} = [chEvents(i).subject '-' chEvents(i).session '-' num2str(chEvents(i).pairNum)];
end

% unique fb pairs
pair_list = unique(fb_pair_lbl);
retain = false(size(pair_list));
for p = 1:length(pair_list)
    ret = strcmp(fb_pair_lbl,pair_list{p});
    ret_last10 = find(ret,10,'last');
    if (mean([fbEvents(ret).correct])>accThresh) &&...
            (mean([fbEvents(ret_last10).correct])>acc10Thresh)
       retain(p) = true;
       filt_fb = filt_fb|strcmp(fb_pair_lbl,pair_list{p});
       filt_ch = filt_ch|strcmp(ch_pair_lbl,pair_list{p});
    end
end

% return filtered lbls
fb_pair_lbl_unfilt = fb_pair_lbl;
ch_pair_lbl_unfilt = ch_pair_lbl;
pair_list = pair_list(retain);
fb_pair_lbl = fb_pair_lbl(filt_fb);
ch_pair_lbl = ch_pair_lbl(filt_ch);



function[filt_fb,filt_ch,pair_list,fb_pair_lbl,ch_pair_lbl] = filtNonLearnPairs_local(fbEvents,chEvents,accThresh,acc10Thresh)
% train only
filt_fb = false(size(fbEvents));
filt_ch = strcmp({chEvents.type},'train');        

% unique subj-sess-pair list for fb and ch
for i = 1:length(fbEvents)
   fb_pair_lbl{i} = [fbEvents(i).subject '-' fbEvents(i).session '-' num2str(fbEvents(i).pairNum)];
end
for i = 1:length(chEvents)
   ch_pair_lbl{i} = [chEvents(i).subject '-' chEvents(i).session '-' num2str(chEvents(i).pairNum)];
end

% unique fb pairs
pair_list = unique(fb_pair_lbl);
retain = false(size(pair_list));
for p = 1:length(pair_list)
    ret = strcmp(fb_pair_lbl,pair_list{p});
    ret_last10 = find(ret,10,'last');
    if (mean([fbEvents(ret).correct])<accThresh) &&...
            (mean([fbEvents(ret_last10).correct])<acc10Thresh)
       retain(p) = true;
       filt_fb = filt_fb|strcmp(fb_pair_lbl,pair_list{p});
       filt_ch = filt_ch|strcmp(ch_pair_lbl,pair_list{p});
    end
end

% return filtered lbls
pair_list = pair_list(retain);
fb_pair_lbl = fb_pair_lbl(filt_fb);
ch_pair_lbl = ch_pair_lbl(filt_ch);