function [elecListStruct] =  ps2_ecog_subjPow_getElecList(uSubj)
% This function gets a list of electrode locations for each subject across
% reimplants/montage changes; removes replicate contacts by comparing
% distances across similarly named electrodes that show up across multiple
% montages
%Inputs:
%uSubj .... unique subject id (e.g., 'TJ045' will get all TJ045 elec
           %locations (including TJ045_1)
%Outputs:
%elecListStruct ... structure of unique electrode locations; lists id; subj
%                   Id, and location information

% if multiple electrodes with the same name across montageCh/reimplants that are not
% in the same location, it creates multiple entries (e.g., '1-2_1',
% '1-2_2')

% To Do:
%( ) allow inputs to toggle which elec coordinates you are using

% get subjList struct
[subjListStruct] = ps2_ecog_subjPow_getSubjList(uSubj);

%
subjList = unique(subjListStruct.subjSessList(:,1));
subj_cell = cell(0,0);
eNames_cell = cell(0,0);
xyz_list = [];
enum_list = [];
anatRegion_cell = cell(0,0);
for s = 1:length(subjList)
    talStruct = getBipolarSubjElecs(subjList{s},1);
    locStruct = [talStruct.avgSurf];
    
    subj_cell = cat(1,subj_cell,repmat(subjList(s),[length(talStruct) 1]));
    eNames_cell = cat(1,eNames_cell,{talStruct.eNames}');
    xyz_list = cat(1,xyz_list,cat(2,[locStruct.x_snap]',...
        [locStruct.y_snap]', [locStruct.z_snap]'));
    enum_list = cat(1,enum_list,cat(1,talStruct.channel));
    anatRegion_cell = cat(1,anatRegion_cell,{locStruct.anatRegion_snap}');
end

%remove replicates
u_eNames = unique(eNames_cell);
elecListStruct = struct();
count = 0;
for e = 1:length(u_eNames)
   
   % find contacts of the same name 
   eIdx =  strcmp(u_eNames{e},eNames_cell);

  
   switch sum(eIdx)
      case 1 %only 1 contact with this name
         count = count+1;
         
         % update
         elecListStruct(count).uSubj = uSubj;
         elecListStruct(count).eNames = u_eNames{e};
         elecListStruct(count).subj_list = subj_cell(eIdx);
         elecListStruct(count).xyz = xyz_list(eIdx,:);
         elecListStruct(count).enum = enum_list(eIdx,:);
         elecListStruct(count).anatRegion = unique(anatRegion_cell{eIdx});
         
         
       otherwise %more than 1 contact
           %  check distance between contacts of the same name
           dist = mean(pdist(xyz_list(eIdx,:)));
           
           if dist == 0 %add 1 entry 
               count = count+1;
               elecListStruct(count).uSubj = uSubj;
               elecListStruct(count).eNames = u_eNames{e};
               elecListStruct(count).subj_list = subj_cell(eIdx);
               elecListStruct(count).xyz = mean(xyz_list(eIdx,:),1);
               elecListStruct(count).enum = mean(enum_list(eIdx,:),1);
               elecListStruct(count).anatRegion = unique(anatRegion_cell(eIdx));
               
               
           else % add multiple entries
                eIdx_list = find(eIdx);
                
                for ee = 1:length(eIdx_list)
                   count = count+1;
                   elecListStruct(count).uSubj = uSubj;
                   elecListStruct(count).eNames = [u_eNames{e} '_' num2str(ee)];
                   elecListStruct(count).subj_list = subj_cell(eIdx_list(ee));
                   elecListStruct(count).xyz = xyz_list(eIdx_list(ee),:);
                   elecListStruct(count).enum = enum_list(eIdx,:);
                   elecListStruct(count).anatRegion = unique(anatRegion_cell(eIdx_list(ee)));
                end%
           end
   end
end


