function[fbPow,chPow,stPow,ret_fb,ret_ch,config] = ps2_ecog_subjPow_getSubjPow(uSubj,eName,configNum);
% This function returns z-scored power for each unique electrode contact.
% Performs z-score within session.
% Outputs:

% parse configNum
if ~exist('configNum','var') || isempty(configNum)
   configNum = 1; % HFA 
end

clear global
global CONFNUM
CONFNUM = configNum;
config = getConfig_local(configNum);

% check if saved already
saveFile = [uSubj '-' eName '.mat'];
cd_mkdir(config.saveDir)

if exist(saveFile,'file')
    load(saveFile)
    
else %compute it
    % get events
    [fbEvents,choiceEvents,stimEvents] = ps2_ecog_subjPow_getSubjEv(uSubj);

    % get elec list
    [eStruct] = ps2_ecog_subjPow_getElecList(uSubj);
    eStruct = eStruct(strcmp({eStruct.eNames},eName));

    % get subs-sess list
    [subjListStruct] = ps2_ecog_subjPow_getSubjList(uSubj); 
    subjSessList = subjListStruct.subjSessList;

    % filter subj-sess list for this contact
    subjSessList = subjSessList(ismember(subjSessList(:,1),eStruct.subj_list),:);

    % collect variables
    % ret variable keep track of which uSubj events are appropriate for this
    % contact. 
    ret_fb = false(1,length(fbEvents)); 
    fbPow = [];
    ret_ch = false(1,length(choiceEvents));
    chPow = []; stPow = [];

    % loop through the key subj-sess, and compute/load power
    for i = 1:size(subjSessList,1)
        % fb Ev
        [thisFbPow,ret] = getPow_local(fbEvents,subjSessList{i,1},subjSessList{i,2},eStruct.enum);
        ret_fb = ret_fb|ret;

        % choice Ev
        [thisChPow,ret] = getPow_local(choiceEvents,subjSessList{i,1},subjSessList{i,2},eStruct.enum);
        ret_ch = ret_ch|ret;

        % stim Ev
        [thisStPow,ret] = getPow_local(stimEvents,subjSessList{i,1},subjSessList{i,2},eStruct.enum);
        ret_ch = ret_ch|ret;    

        % Normalize within this session
        [thisFbPow,thisChPow,thisStPow] = zscore_local(thisFbPow,thisChPow,thisStPow);

        % cat pow
        fbPow = cat(3,fbPow,thisFbPow);
        chPow = cat(3,chPow,thisChPow);
        stPow = cat(3,stPow,thisStPow);
    end
    % save power
    cd(config.saveDir)
    powConfig = config; 
    save(saveFile,'fbPow','chPow','stPow','ret_fb','ret_ch','powConfig')
end

% FUNCTIONS %
function[POW,ret] = getPow_local(ev,subj,sess,elecNum)
% get config
global CONFNUM
[config] = getConfig_local(CONFNUM);

%filter events
ret = strcmp({ev.subject},subj)&strcmp({ev.session},sess);
ev = ev(ret);

% EEG
[EEG] = gete_ms_wrapper(elecNum,ev,config.priorMS+config.postMS,...
               -config.priorMS,config.buffer);
% POW
[POW] = eeg2PowAndPhase(EEG,config.freQ,config.buffer,config.logBefMeanFlag,[],config.waveNum); 
% downsample Pow
[POW] = pow2timeFreqBins(POW,config.timeWin,config.timeStep,config.freQ,config.freqBins,...
        config.logAfterMeanFlag);  
    
    
function [outStruct] = getConfig_local(configNum)

%to do: edit get power to do different normalization methods
switch configNum
    case 1 %HFA; 
        outStruct.freQ =  logspace(log10(70), log10(200),30);
        outStruct.freqBins = logspace(log10(70), log10(200),30);  

        outStruct.timeWin = 200; 
        outStruct.timeStep = 10;
end

%save dir
dirs = ps2_dirs;
outStruct.saveDir = fullfile(dirs.analyses,'ecog','subjPow','savedPower');

%constants:
outStruct.configNum = configNum;
outStruct.priorMS = 1000;
outStruct.postMS = 2000;
outStruct.bipolFlag = 1;
outStruct.filtFlag = 0; %60Hz filtFlag
outStruct.logBefMeanFlag = 1; %
outStruct.logAfterMeanFlag = 0;% these CANNOT both be set to 1 
outStruct.buffer = 1000;
outStruct.waveNum = 7;

% time bins
dur = outStruct.priorMS+outStruct.postMS;
tWin = outStruct.timeWin;
tStep = outStruct.timeStep;
tEnds = tWin:tStep:dur;tStarts = tEnds - tWin+1;
outStruct.timeWins = [tStarts',tEnds']; 
outStruct.timeWins_lbl = nanmean(outStruct.timeWins,2)'-outStruct.priorMS;

%z Flag params
% baseline time wins of interest
outStruct.base_tWins.stim = [0 500];
outStruct.base_tWins.choice = [-750 0];
outStruct.base_tWins.fb = [0 2000];
%--------%
outStruct.configID = num2str(configNum); 

function [fbPower,choicePower,stimPower,meanPow,stdPow] = zscore_local(fbPow,chPow,stPow)
% get config
global CONFNUM
[config] = getConfig_local(CONFNUM);

zFlag = 1;
switch zFlag 
    case 1 % wtihin events normalization

    [~,stim_start] = min(abs(config.timeWins_lbl - config.base_tWins.stim(1)));
    [~,stim_end] = min(abs(config.timeWins_lbl  - config.base_tWins.stim(2)));

    [~,choice_start] = min(abs(config.timeWins_lbl  - config.base_tWins.choice(1)));
    [~,choice_end] = min(abs(config.timeWins_lbl  - config.base_tWins.choice(2)));

    [~,fb_start] = min(abs(config.timeWins_lbl  - config.base_tWins.fb(1)));
    [~,fb_end] = min(abs(config.timeWins_lbl  - config.base_tWins.fb(2)));
    % TF type analyses
    
    % get mean and std for TF powers, tilt, and BB
    meanPow(:,1) = nanmean(nanmean(stPow(:,stim_start:stim_end,:),3),2);
    meanPow(:,2) = nanmean(nanmean(chPow(:,choice_start:choice_end,:),3),2);       
    meanPow(:,3) = nanmean(nanmean(fbPow(:,fb_start:fb_end,:),3),2);
    meanPow = mean(meanPow,2);

    stdPow(:,1) = std(nanmean(stPow(:,stim_start:stim_end,:),2),[],3);
    stdPow(:,2) = std(nanmean(chPow(:,choice_start:choice_end,:),2),[],3);       
    stdPow(:,3) = std(nanmean(fbPow(:,fb_start:fb_end,:),2),[],3);
    stdPow = mean(stdPow,2);        

    %z score pow
    stimPower = zScorePow(stPow,meanPow,stdPow);
    choicePower = zScorePow(chPow,meanPow,stdPow);
    fbPower = zScorePow(fbPow,meanPow,stdPow);
end

