function[modelStats,paramStruct] = ps2_ecog_subjPow_rlModel(uSubj,filtLbl,modelLbl)
% This function applies a rl model to feedback trials that have been
% filtered based on some criteria (filtLbl). 

config = getConfig_local(modelLbl);

% check param structure
saveDir = fullfile(config.saveDir,[filtLbl '-' modelLbl]);
saveFile = [uSubj '.mat'];
cd_mkdir(saveDir)
if exist([saveFile],'file')
    load(saveFile,'modelStats','paramStruct')
else
    % get events
    [fbEvents] = ps2_ecog_subjPow_getSubjEv(uSubj);
    [filt_fb,~,pair_list,fb_pair_lbl] = ...
        ps2_ecog_subjPow_filtSubjEv(uSubj,filtLbl);

    if sum(filt_fb) == 0
        modelStats = [];paramStruct = [];
        return
    end
    fbEvents = fbEvents(filt_fb);

    % paramstruct
    [~,paramStruct] = getConfig_local(modelLbl);

    % get rVec, and button vec for each item
    [rVecCell,bVecCell] = ...
        events2Vec_local(fbEvents,pair_list,fb_pair_lbl);
    
    % do grid search and apply RL model
    [modelStats] = applyModel_wrapper_local(paramStruct,...
        fbEvents,rVecCell,bVecCell,pair_list,fb_pair_lbl);
    
    %find best overall fit
    [~,idx] = min([modelStats.sumSq]);
    %[~,idx] = max([modelStats.LLE]);
    modelStats = modelStats(idx);    
    paramStruct = paramStruct(idx);
    
    % save
    cd(saveDir)
    save(saveFile,'modelStats','paramStruct');
end

% %keyboard
% swagFig([0.1680    0.7795    0.8098    0.1717]);hold all
% plot(smoothBinaryVec([fbEvents.correct],2,1),'r','linewidth',2);set(gca,'ylim',[-.2 1.2])
% plot(modelStats.p_choice,'--b','linewidth',1);set(gca,'ylim',[-.2 1.2])
% disp(['pSq ' num2str(modelStats.pseudRSq) '...sumSq ' num2str(modelStats.sumSq)])
% FUNCTIONS %
function[config,paramStruct] = getConfig_local(modelLbl);
dirs = ps2_dirs;
%default config
config.modelLbl = modelLbl;
config.decayFcn = 'exp'; 
config.noFbDecay = 0;
config.winSize = 5;
config.winStep = 6;
config.saveDir = fullfile(dirs.analyses,'ecog','subjPow','rlModel');

% default param settings
def.alpha_w = 0; % learning rate for wins (forgetting function)
def.alpha_l = 0; % learning rate for losses
def.alpha_d = 0; % learning rate for no fb trials
def.alpha_button = 0;
def.beta = 0.1; % 0 is high exploitation; 1 is high exploration (default = some noise)
def.w_a = 0; %weigthing parameter that controls the relative strength of action-reward assoc
def.Qi = 0.5; %starting expectancy values
        
% rule-based (Ashby Maddox 98, pp. 459)
def.alpha_rb = 0;
def.gamma = 0; %perseveration
def.lamda = 0; %motivation
def.rul_qi = 0.5;  
def.lr_bias = 0.15;%0.15; % penalize or strengthen action rules

% weighting (b/w Q and RB models; Glasher 2010) 
def.w_rb_i = 0; %offset (default =weighted to Q)
def.w_rb_k = 0; %decay constant for RB weight function

param_vals = [0.01:0.1:1];
count = 0;
switch modelLbl
    %%%%% BASIC MODELS
    case 'qPos'
        for i = 1:length(param_vals)
                count = count+1;
                paramStruct(count) = def;
                paramStruct(count).alpha_w = param_vals(i);
                paramStruct(count).alpha_l = param_vals(i);
                paramStruct(count).beta = 0.1;
        end
    case 'rbPos'
        for i = 1:length(param_vals)
            for j = 1:length(param_vals)
                count = count+1;
                paramStruct(count) = def;
                paramStruct(count).alpha_rb = param_vals(i);
                paramStruct(count).beta = 0.01; 
                % weight completely to rule-based
                paramStruct(count).w_rb_i = 1;
            end
        end
     case 'qPosBeta'
        for i = 1:length(param_vals)
            for j = 1:length(param_vals)
                count = count+1;
                paramStruct(count) = def;
                paramStruct(count).alpha_w = param_vals(i);
                paramStruct(count).alpha_l = param_vals(i);
                paramStruct(count).beta = param_vals(j);
            end
        end
     case 'rbPosBeta'
        for i = 1:length(param_vals)
            for j = 1:length(param_vals)
                count = count+1;
                paramStruct(count) = def;
                paramStruct(count).alpha_rb = param_vals(i);
                paramStruct(count).beta = param_vals(j);
                
                % weight completely to rule-based
                paramStruct(count).w_rb_i = 1;
                
            end
        end
    case 'rbPosLamda'
        for i = 1:length(param_vals)
            for j = 1:length(param_vals)
                count = count+1;
                paramStruct(count) = def;
                paramStruct(count).alpha_rb = param_vals(i);
                paramStruct(count).lamda = param_vals(j);
                paramStruct(count).beta = 0.01; 
                % weight completely to rule-based
                paramStruct(count).w_rb_i = 1;
                
            end
        end
    case 'rbPosBetaLamda'
        for i = 1:length(param_vals)
            for j = 1:length(param_vals)
                for k = 1:length(param_vals)
                    count = count+1;
                    paramStruct(count) = def;
                    paramStruct(count).alpha_rb = param_vals(i);
                    paramStruct(count).lamda = param_vals(j);
                    paramStruct(count).beta = param_vals(k);%0.01; 
                    % weight completely to rule-based
                    paramStruct(count).w_rb_i = 1;
                end
            end
        end
  
    %%%%% Additional models
    case 'qPosNeg'
        for i = 1:length(param_vals)
            for j = 1:length(param_vals)
                count = count+1;
                paramStruct(count) = def;
                paramStruct(count).alpha_w = param_vals(i);
                paramStruct(count).alpha_l = param_vals(j);
            end
        end
    case 'qPosNegBeta'
        for i = 1:length(param_vals)
            for j = 1:length(param_vals)
                for k = 1:length(param_vals)
                    count = count+1;
                    paramStruct(count) = def;
                    paramStruct(count).alpha_w = param_vals(i);
                    paramStruct(count).alpha_l = param_vals(j);
                    paramStruct(count).beta = param_vals(k);
                end
            end
        end
    case 'qPosBetaWa'
        for i = 1:length(param_vals)
            for j = 1:length(param_vals)
                for k = 1:length(param_vals)
                    count = count+1;
                    paramStruct(count) = def;
                    paramStruct(count).alpha_w = param_vals(i);
                    paramStruct(count).alpha_l = param_vals(i);
                    paramStruct(count).alpha_button = param_vals(i);
                    paramStruct(count).beta = param_vals(j);
                    paramStruct(count).w_a = param_vals(k);
                end
            end
        end
end

function [rVec,bVec] = events2Vec_local(fbEvents,pair_list,fb_pair_lbl)
%%%% These cell arrays store reward associations for each item and action
%%%% throughout the entire session

    rVec = cell(1,2*length(pair_list));
    correct = [fbEvents.correct];
    fb = [fbEvents.fb];
    button = [fbEvents.button];
    
    for i = 1: length(pair_list)
       ret = strcmp(fb_pair_lbl,pair_list{i});
        
       %hi prob
       rVec{(2*i)-1} = zeros(1,length(correct));
       rVec{(2*i)-1}(ret&correct==1&fb==1) = 1;
       rVec{(2*i)-1}(ret&correct==1&fb==0) = -1;
       %low prob
       rVec{(2*i)} = zeros(1,length(correct));
       rVec{(2*i)}(ret&correct==0&fb==1) = 1;
       rVec{(2*i)}(ret&correct==0&fb==0) = -1;
    end
    %left
    bVec{1} = zeros(1,length(correct));
    bVec{1}(button == 1&fb==1)  = 1;
    bVec{1}(button == 1&fb==0)  = -1;
    %right
    bVec{2} = zeros(1,length(correct));
    bVec{2}(button == 2&fb==1)  = 1;
    bVec{2}(button == 2&fb==0)  = -1;

function[behStruct] = applyModel_wrapper_local(paramStruct,fbEvents,rVecCell,bVecCell,pair_list,fb_pair_lbl)
% j is the pair number to focus on 
% loop through each param set
behStruct = struct();
for i = 1:length(paramStruct)
    %apply model (get rew exp and LLE)
    if i == 1
        behStruct = applyModel_local(paramStruct(i),fbEvents,rVecCell,bVecCell,pair_list,fb_pair_lbl);
    else
        behStruct(i) = applyModel_local(paramStruct(i),fbEvents,rVecCell,bVecCell,pair_list,fb_pair_lbl);
    end
    disp(i)
    %if mod(i,20) == 0
    %    disp([num2str(i) '/' num2str(length(paramStruct))])
    %end
end

function[behStruct] = applyModel_local(paramsStruct,fbEvents,rVecCell,bVecCell,pair_list,fb_pair_lbl)
%initialize rew expec for each item and button
itemList = 1:length(rVecCell);
for i = itemList
    [expVec_item(i)] = {paramsStruct.Qi*ones(size(rVecCell{i}))};
    [rulVec_item(i)] = {paramsStruct.rul_qi*ones(size(rVecCell{i}))};    
end

%initialize rew expec for each item
buttonList = 1:length(bVecCell);
for i = buttonList
    [expVec_button(i)] = {paramsStruct.Qi*ones(size(bVecCell{i}))};
    %[rulVec_button(i)] = {paramsStruct.rul_qi*ones(size(rVecCell{i}))};   
end

%arrang vec
arrangVec = [fbEvents.pcorr_left]>[fbEvents.pcorr_right]; %high-prob item on left
correct = [fbEvents.correct];

% active_rules for each pair are cached iteratively updated.
% subject's first choice is used as the first active rule


for p = 1:length(pair_list)
   retain = find(strcmp(fb_pair_lbl,pair_list{p}),1);
    if fbEvents(retain).correct == 1
       active_rule{p} = 1;
    else
       active_rule{p} = 2;
    end
end
for t = 1:(length(fbEvents)) 
    %which pair is this?
    pairIdx = find(strcmp(fb_pair_lbl{t},pair_list));
    
    % first, calc p choice (for current trial), given expVals and active_rule 
    hiProbIdx = (2*pairIdx)-1;
    loProbIdx = (2*pairIdx);
    leftIdx = 1;
    rightIdx = 2;
    
    
    [p_choice(t),p_a(t),p_l(t),exp_choice(t),exp_other(t),...
        exp_choice_item(t),exp_other_item(t),exp_choice_button(t),exp_other_button(t)] = ...
        calcPChoice_local(expVec_item{hiProbIdx}(t),expVec_item{loProbIdx}(t),...
        expVec_button{leftIdx}(t),expVec_button{rightIdx}(t),active_rule{pairIdx},...
        correct(t),arrangVec(t),paramsStruct.beta,paramsStruct.w_a,...
        paramsStruct.w_rb_i,paramsStruct.w_rb_k,t);
    
    % second update expectancies on the subsequent trial
    % also, update the rule_values and the active_rule for this pair based on the feedback
    % which item was selected?
    if t < find(strcmp(fb_pair_lbl{t},fb_pair_lbl),1,'last'); %the last feedback trial doesnt matter

        if fbEvents(t).correct == 1
            itemIdx = (2*pairIdx)-1;
        else
            itemIdx = (2*pairIdx);
        end

        % positive or negative feedback?
        if fbEvents(t).fb == 1
            alfa = paramsStruct.alpha_w;
        elseif fbEvents(t).fb == 0
            alfa = paramsStruct.alpha_l;
        end
        alfa_rb = paramsStruct.alpha_rb; %to update rule salience

        % update chosen item and rule expectancy
        expVec_item{itemIdx}(t+1) = updateExpec_local(expVec_item{itemIdx}(t),fbEvents(t).fb,alfa); 
        rulVec_item{itemIdx}(t+1) = updateExpec_local(rulVec_item{itemIdx}(t),fbEvents(t).fb,alfa_rb); 

        %update all other item and rule expectancies (these are no feedback trials, use
        %alpha_d). When alpha_d is 0 it just carries through the currently
        %held expectations
        otherItemList = find(~(itemIdx==itemList));
        for otherItemIdx = otherItemList
            expVec_item{otherItemIdx}(t+1) = updateExpec_local(expVec_item{otherItemIdx}(t),fbEvents(t).fb,paramsStruct.alpha_d); 
            rulVec_item{otherItemIdx}(t+1) = updateExpec_local(rulVec_item{otherItemIdx}(t),fbEvents(t).fb,paramsStruct.alpha_d); 
        end

        %which button was chosen?
        if fbEvents(t).button == 1
            buttonIdx = 1;
            otherButtonIdx = 2;
        elseif fbEvents(t).button == 2
            buttonIdx = 2;
            otherButtonIdx = 1;
        end

        % update chosen and other button expectancy
        if ~(fbEvents(t).button == 0)
            expVec_button{buttonIdx}(t+1) = ...
                updateExpec_local(expVec_button{buttonIdx}(t),fbEvents(t).fb,paramsStruct.alpha_button); 
            expVec_button{otherButtonIdx}(t+1) = ...
                updateExpec_local(expVec_button{otherButtonIdx}(t),fbEvents(t).fb,paramsStruct.alpha_d); 
        else % this is for when button is not pressed in lrchoice
            expVec_button{1}(t+1) = expVec_button{1}(t);
            expVec_button{2}(t+1) = expVec_button{2}(t);
        end
        %record current state of rule-based system
        sess_rul_a(t) = rulVec_item{hiProbIdx}(t);
        sess_rul_b(t) = rulVec_item{loProbIdx}(t);        
        sess_active_rule(t) = active_rule{pairIdx};
    
        % Rule-switch:
        % if fb is incorrect, consider switching based on other rule values
        if fbEvents(t).fb == 0 
                % initialize weights with each rule
                rule_weights = zeros(1,2);
                
                % bias the previous rule strength by preseveration (gamma)
                rule_weights(active_rule{pairIdx}) = paramsStruct.gamma + rule_weights(active_rule{pairIdx});

                % what are the alternative rules available?
                other_rules = find(~(active_rule{pairIdx}==[1:2]));

                % select new rule to hypothesis test, and bias that with
                % lamda (seems like unecessary machinery for this task with only 2 rules).
                new_rule = randi([min(other_rules),max(other_rules)]);
                rule_weights(new_rule) = paramsStruct.lamda + rule_weights(new_rule);
                
                % compute weighting vector
                rul_vec = rule_weights + [rulVec_item{hiProbIdx}(t+1) rulVec_item{loProbIdx}(t+1)];
                
                % perform switch (shuffling ensures that ties are resolved
                % randomly)
                [~,idx] = sort(randi([1,10000],[1 2]));
                [~,max_idx] = max(rul_vec(idx));
                active_rule{pairIdx} = idx(max_idx);
        end
    end
end

%calc LLE
[LLE,pseudRSq,sumSq]  = goodnessFit_local(p_choice);

%update behStruct
behStruct.exp_choice = exp_choice;
behStruct.exp_other = exp_other;
behStruct.exp_choice_item = exp_choice_item;
behStruct.exp_other_item = exp_other_item;
behStruct.exp_choice_button = exp_choice_button;
behStruct.exp_other_button = exp_other_button;
behStruct.active_rule = sess_active_rule;
behStruct.rul_a = sess_rul_a;
behStruct.rul_b = sess_rul_b;
behStruct.p_choice = p_choice;
behStruct.p_a = p_a; %(high-prob item)
behStruct.p_l = p_l; %(left)
behStruct.LLE = LLE;
behStruct.pseudRSq = pseudRSq;
behStruct.sumSq = sumSq;

%%
function [LLEvec,pseudoRsq,sumSq]  = goodnessFit_local(p_choice)
LLEvec = 0; rVec = 0;
for i = 1:length(p_choice)
    LLEvec =  LLEvec + log(p_choice(i));
    rVec = rVec + log(0.5);
end

pseudoRsq = (rVec-LLEvec)/rVec;
sumSq = sum((1-p_choice).^2)/length(p_choice);
%% calc p choice_local
function[p_choice,p_a,p_l,exp_choice,exp_other,...
    exp_choice_item,exp_other_item,exp_choice_button,exp_other_button]...
    = calcPChoice_local(exp_a,exp_b,exp_l,exp_r,active_rule,...
    chosenItem,arrang,beta,button_weight,rb_weight_i,rb_weight_k,t)

% active_rule signals the active rule
switch active_rule
    case 1 % choose a (correct)
         rul_a = .99;
         rul_b = .01;
    case 2 % choose b (incorrect)
         rul_b = .99;
         rul_a = .01;
end

%choice vs. other
if chosenItem == 1 % A chosen        
    if arrang == 1 % left button chosen 
        q_exp_choice = (button_weight*exp_l)+((1-button_weight)*exp_a);
        q_exp_other = (button_weight*exp_r)+((1-button_weight)*exp_b);
        lFlag = 1;
    else % right button chosen
        q_exp_choice = (button_weight*exp_r)+((1-button_weight)*exp_a);
        q_exp_other = (button_weight*exp_l)+((1-button_weight)*exp_b);
        
        lFlag = 0;
    end
    aFlag = 1;        
    rul_exp_choice = rul_a;
    rul_exp_other = rul_b;
else % B chosen
    if arrang == 1 % right button chosen
        q_exp_choice = (button_weight*exp_r)+((1-button_weight)*exp_b);
        q_exp_other = (button_weight*exp_l)+((1-button_weight)*exp_a);
        lFlag = 0;
    else %left button chosen
        q_exp_choice = (button_weight*exp_l)+((1-button_weight)*exp_b);
        q_exp_other = (button_weight*exp_r)+((1-button_weight)*exp_a);
        lFlag = 1;
    end
    aFlag = 0;
    rul_exp_choice = rul_b;
    rul_exp_other = rul_a;
end

% weight with Q and rule-based system
w_rb = rb_weight_i*exp(-rb_weight_k*t); %this weighting functions declines with time if rb_weight_k > 0
exp_choice = w_rb*rul_exp_choice + (1-w_rb)*q_exp_choice;
exp_other = w_rb*rul_exp_other + (1-w_rb)*q_exp_other;


% compute probability
p_choice = exp(exp_choice/beta)/((exp(exp_choice/beta)+exp(exp_other/beta)));

if aFlag == 1
    p_a = p_choice;
    exp_choice_item = exp_a;
    exp_other_item = exp_b;
else
    p_a = 1-p_choice;
    exp_choice_item = exp_b;
    exp_other_item = exp_a;
end
if lFlag == 1;
    p_l = p_choice;
    exp_choice_button = exp_l;
    exp_other_button = exp_r;
else
    p_l = 1-p_choice;
    exp_choice_button = exp_r;
    exp_other_button = exp_l;
end


%% updateExpec_local
function[exp_a] = updateExpec_local(exp_a,r,alpha)
%This module updates the reward expectancy associated with an item/action
% based on the obtained outcome and a learning rate parameter
% r must be 0 or 1
exp_a = exp_a + alpha*(r - exp_a);

% exp_a is bounded between 0.01 and 0.99
exp_a = min([exp_a 0.99]);
exp_a = max([exp_a 0.01]);


